=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2009-02-08 11:11:30 +0000
+++ client/drizzle.cc	2009-02-08 11:28:58 +0000
@@ -217,8 +217,8 @@
 
 static const CHARSET_INFO *charset_info= &my_charset_utf8_general_ci;
 
-int drizzle_real_query_for_lazy(const char *buf, int length);
-int drizzle_store_result_for_lazy(DRIZZLE_RES **result);
+int drizzleclient_real_query_for_lazy(const char *buf, int length);
+int drizzleclient_store_result_for_lazy(DRIZZLE_RES **result);
 
 
 void tee_fprintf(FILE *file, const char *fmt, ...);
@@ -1156,7 +1156,7 @@
 
   sprintf(output_buff,
           _("Your Drizzle connection id is %u\nServer version: %s\n"),
-          drizzle_thread_id(&drizzle),
+          drizzleclient_thread_id(&drizzle),
           server_version_string(&drizzle));
   put_info(output_buff, INFO_INFO, 0, 0);
 
@@ -1207,7 +1207,7 @@
 
 void drizzle_end(int sig)
 {
-  drizzle_close(&drizzle);
+  drizzleclient_close(&drizzle);
   if (!status.batch && !quick && histfile)
   {
     /* write-history */
@@ -1259,17 +1259,17 @@
     goto err;
   }
 
-  kill_drizzle= drizzle_create(kill_drizzle);
-  if (!drizzle_connect(kill_drizzle,current_host, current_user, opt_password,
+  kill_drizzle= drizzleclient_create(kill_drizzle);
+  if (!drizzleclient_connect(kill_drizzle,current_host, current_user, opt_password,
                           "", opt_drizzle_port, opt_drizzle_unix_port,0))
   {
     goto err;
   }
 
   /* kill_buffer is always big enough because max length of %lu is 15 */
-  sprintf(kill_buffer, "KILL /*!50000 QUERY */ %u", drizzle_thread_id(&drizzle));
-  drizzle_real_query(kill_drizzle, kill_buffer, strlen(kill_buffer));
-  drizzle_close(kill_drizzle);
+  sprintf(kill_buffer, "KILL /*!50000 QUERY */ %u", drizzleclient_thread_id(&drizzle));
+  drizzleclient_real_query(kill_drizzle, kill_buffer, strlen(kill_buffer));
+  drizzleclient_close(kill_drizzle);
   tee_fprintf(stdout, _("Query aborted by Ctrl+C\n"));
 
   interrupted_query= 1;
@@ -1471,7 +1471,7 @@
   const char* readline= "readline";
 
   printf(_("%s  Ver %s Distrib %s, for %s (%s) using %s %s\n"),
-         my_progname, VER, drizzle_get_client_info(),
+         my_progname, VER, drizzleclient_get_client_info(),
          SYSTEM_TYPE, MACHINE_TYPE,
          readline, rl_library_version);
 
@@ -1668,7 +1668,7 @@
 {
   char *tmp, *pagpoint;
   int ho_error;
-  const DRIZZLE_PARAMETERS *drizzle_params= drizzle_get_parameters();
+  const DRIZZLE_PARAMETERS *drizzle_params= drizzleclient_get_parameters();
 
   tmp= (char *) getenv("DRIZZLE_HOST");
   if (tmp)
@@ -2369,35 +2369,35 @@
   /* hash Drizzle functions (to be implemented) */
 
   /* hash all database names */
-  if (drizzle_query(&drizzle,"show databases") == 0)
+  if (drizzleclient_query(&drizzle,"show databases") == 0)
   {
-    if (!(databases = drizzle_store_result(&drizzle)))
-      put_info(drizzle_error(&drizzle),INFO_INFO,0,0);
+    if (!(databases = drizzleclient_store_result(&drizzle)))
+      put_info(drizzleclient_error(&drizzle),INFO_INFO,0,0);
     else
     {
-      while ((database_row=drizzle_fetch_row(databases)))
+      while ((database_row=drizzleclient_fetch_row(databases)))
       {
         char *str=strdup_root(&hash_mem_root, (char*) database_row[0]);
         if (str)
           add_word(&ht,(char*) str);
       }
-      drizzle_free_result(databases);
+      drizzleclient_free_result(databases);
     }
   }
   /* hash all table names */
-  if (drizzle_query(&drizzle,"show tables")==0)
+  if (drizzleclient_query(&drizzle,"show tables")==0)
   {
-    if (!(tables = drizzle_store_result(&drizzle)))
-      put_info(drizzle_error(&drizzle),INFO_INFO,0,0);
+    if (!(tables = drizzleclient_store_result(&drizzle)))
+      put_info(drizzleclient_error(&drizzle),INFO_INFO,0,0);
     else
     {
-      if (drizzle_num_rows(tables) > 0 && !opt_silent && write_info)
+      if (drizzleclient_num_rows(tables) > 0 && !opt_silent && write_info)
       {
         tee_fprintf(stdout, _("\
 Reading table information for completion of table and column names\n    \
 You can turn off this feature to get a quicker startup with -A\n\n"));
       }
-      while ((table_row=drizzle_fetch_row(tables)))
+      while ((table_row=drizzleclient_fetch_row(tables)))
       {
         char *str=strdup_root(&hash_mem_root, (char*) table_row[0]);
         if (str &&
@@ -2412,29 +2412,29 @@
   {
     return;
   }
-  drizzle_data_seek(tables,0);
+  drizzleclient_data_seek(tables,0);
   if (!(field_names= (char ***) alloc_root(&hash_mem_root,sizeof(char **) *
-                                           (uint) (drizzle_num_rows(tables)+1))))
+                                           (uint) (drizzleclient_num_rows(tables)+1))))
   {
-    drizzle_free_result(tables);
+    drizzleclient_free_result(tables);
     return;
   }
   i=0;
-  while ((table_row=drizzle_fetch_row(tables)))
+  while ((table_row=drizzleclient_fetch_row(tables)))
   {
-    if ((fields=drizzle_list_fields(&drizzle,(const char*) table_row[0],NULL)))
+    if ((fields=drizzleclient_list_fields(&drizzle,(const char*) table_row[0],NULL)))
     {
-      num_fields=drizzle_num_fields(fields);
+      num_fields=drizzleclient_num_fields(fields);
       if (!(field_names[i] = (char **) alloc_root(&hash_mem_root,
                                                   sizeof(char *) *
                                                   (num_fields*2+1))))
       {
-        drizzle_free_result(fields);
+        drizzleclient_free_result(fields);
         break;
       }
       field_names[i][num_fields*2]= '\0';
       j=0;
-      while ((sql_field=drizzle_fetch_field(fields)))
+      while ((sql_field=drizzleclient_fetch_field(fields)))
       {
         sprintf(buf,"%.64s.%.64s",table_row[0],sql_field->name);
         field_names[i][j] = strdup_root(&hash_mem_root,buf);
@@ -2446,14 +2446,14 @@
           add_word(&ht,field_names[i][num_fields+j]);
         j++;
       }
-      drizzle_free_result(fields);
+      drizzleclient_free_result(fields);
     }
     else
       field_names[i]= 0;
 
     i++;
   }
-  drizzle_free_result(tables);
+  drizzleclient_free_result(tables);
   field_names[i]=0;        // End pointer
   return;
 }
@@ -2508,13 +2508,13 @@
   free(current_db);
   current_db= NULL;
   /* In case of error below current_db will be NULL */
-  if (!drizzle_query(&drizzle, "SELECT DATABASE()") &&
-      (res= drizzle_use_result(&drizzle)))
+  if (!drizzleclient_query(&drizzle, "SELECT DATABASE()") &&
+      (res= drizzleclient_use_result(&drizzle)))
   {
-    DRIZZLE_ROW row= drizzle_fetch_row(res);
+    DRIZZLE_ROW row= drizzleclient_fetch_row(res);
     if (row[0])
       current_db= strdup(row[0]);
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
   }
 }
 
@@ -2522,15 +2522,15 @@
  The different commands
 ***************************************************************************/
 
-int drizzle_real_query_for_lazy(const char *buf, int length)
+int drizzleclient_real_query_for_lazy(const char *buf, int length)
 {
   for (uint retry=0;; retry++)
   {
     int error;
-    if (!drizzle_real_query(&drizzle,buf,length))
+    if (!drizzleclient_real_query(&drizzle,buf,length))
       return 0;
     error= put_error(&drizzle);
-    if (drizzle_errno(&drizzle) != CR_SERVER_GONE_ERROR || retry > 1 ||
+    if (drizzleclient_errno(&drizzle) != CR_SERVER_GONE_ERROR || retry > 1 ||
         !opt_reconnect)
       return error;
     if (reconnect())
@@ -2538,12 +2538,12 @@
   }
 }
 
-int drizzle_store_result_for_lazy(DRIZZLE_RES **result)
+int drizzleclient_store_result_for_lazy(DRIZZLE_RES **result)
 {
-  if ((*result=drizzle_store_result(&drizzle)))
+  if ((*result=drizzleclient_store_result(&drizzle)))
     return 0;
 
-  if (drizzle_error(&drizzle)[0])
+  if (drizzleclient_error(&drizzle)[0])
     return put_error(&drizzle);
   return 0;
 }
@@ -2630,7 +2630,7 @@
 
   timer=start_timer();
   executing_query= 1;
-  error= drizzle_real_query_for_lazy(buffer->c_str(),buffer->length());
+  error= drizzleclient_real_query_for_lazy(buffer->c_str(),buffer->length());
 
   if (status.add_to_history)
   {
@@ -2650,7 +2650,7 @@
 
     if (quick)
     {
-      if (!(result=drizzle_use_result(&drizzle)) && drizzle_field_count(&drizzle))
+      if (!(result=drizzleclient_use_result(&drizzle)) && drizzleclient_field_count(&drizzle))
       {
         error= put_error(&drizzle);
         goto end;
@@ -2658,7 +2658,7 @@
     }
     else
     {
-      error= drizzle_store_result_for_lazy(&result);
+      error= drizzleclient_store_result_for_lazy(&result);
       if (error)
         goto end;
     }
@@ -2671,7 +2671,7 @@
     /* Every branch must truncate  buff . */
     if (result)
     {
-      if (!drizzle_num_rows(result) && ! quick && !column_types_flag)
+      if (!drizzleclient_num_rows(result) && ! quick && !column_types_flag)
       {
         strcpy(buff, _("Empty set"));
       }
@@ -2687,23 +2687,23 @@
           print_table_data(result);
         sprintf(buff,
                 ngettext("%ld row in set","%ld rows in set",
-                         (long) drizzle_num_rows(result)),
-                (long) drizzle_num_rows(result));
+                         (long) drizzleclient_num_rows(result)),
+                (long) drizzleclient_num_rows(result));
         end_pager();
-        if (drizzle_errno(&drizzle))
+        if (drizzleclient_errno(&drizzle))
           error= put_error(&drizzle);
       }
     }
-    else if (drizzle_affected_rows(&drizzle) == ~(uint64_t) 0)
+    else if (drizzleclient_affected_rows(&drizzle) == ~(uint64_t) 0)
       strcpy(buff,_("Query OK"));
     else
       sprintf(buff, ngettext("Query OK, %ld row affected",
                              "Query OK, %ld rows affected",
-                             (long) drizzle_affected_rows(&drizzle)),
-              (long) drizzle_affected_rows(&drizzle));
+                             (long) drizzleclient_affected_rows(&drizzle)),
+              (long) drizzleclient_affected_rows(&drizzle));
 
     pos= strchr(buff, '\0');
-    if ((warnings= drizzle_warning_count(&drizzle)))
+    if ((warnings= drizzleclient_warning_count(&drizzle)))
     {
       *pos++= ',';
       *pos++= ' ';
@@ -2714,16 +2714,16 @@
     }
     strcpy(pos, time_buff);
     put_info(buff,INFO_RESULT,0,0);
-    if (drizzle_info(&drizzle))
-      put_info(drizzle_info(&drizzle),INFO_RESULT,0,0);
+    if (drizzleclient_info(&drizzle))
+      put_info(drizzleclient_info(&drizzle),INFO_RESULT,0,0);
     put_info("",INFO_RESULT,0,0);      // Empty row
 
-    if (result && !drizzle_eof(result))  /* Something wrong when using quick */
+    if (result && !drizzleclient_eof(result))  /* Something wrong when using quick */
       error= put_error(&drizzle);
     else if (unbuffered)
       fflush(stdout);
-    drizzle_free_result(result);
-  } while (!(err= drizzle_next_result(&drizzle)));
+    drizzleclient_free_result(result);
+  } while (!(err= drizzleclient_next_result(&drizzle)));
   if (err >= 1)
     error= put_error(&drizzle);
 
@@ -2859,7 +2859,7 @@
   DRIZZLE_FIELD   *field;
   uint i=0;
 
-  while ((field = drizzle_fetch_field(result)))
+  while ((field = drizzleclient_fetch_field(result)))
   {
     tee_fprintf(PAGER, "Field %3u:  `%s`\n"
                 "Catalog:    `%s`\n"
@@ -2893,16 +2893,16 @@
 
   separator.reserve(256);
 
-  num_flag=(bool*) malloc(sizeof(bool)*drizzle_num_fields(result));
+  num_flag=(bool*) malloc(sizeof(bool)*drizzleclient_num_fields(result));
   if (column_types_flag)
   {
     print_field_types(result);
-    if (!drizzle_num_rows(result))
+    if (!drizzleclient_num_rows(result))
       return;
-    drizzle_field_seek(result,0);
+    drizzleclient_field_seek(result,0);
   }
   separator.append("+");
-  while ((field = drizzle_fetch_field(result)))
+  while ((field = drizzleclient_fetch_field(result)))
   {
     uint32_t x, length= 0;
 
@@ -2943,9 +2943,9 @@
   tee_puts((char*) separator.c_str(), PAGER);
   if (column_names)
   {
-    drizzle_field_seek(result,0);
+    drizzleclient_field_seek(result,0);
     (void) tee_fputs("|", PAGER);
-    for (uint off=0; (field = drizzle_fetch_field(result)) ; off++)
+    for (uint off=0; (field = drizzleclient_fetch_field(result)) ; off++)
     {
       uint name_length= (uint) strlen(field->name);
       uint numcells= charset_info->cset->numcells(charset_info,
@@ -2962,14 +2962,14 @@
     tee_puts((char*) separator.c_str(), PAGER);
   }
 
-  while ((cur= drizzle_fetch_row(result)))
+  while ((cur= drizzleclient_fetch_row(result)))
   {
     if (interrupted_query)
       break;
-    uint32_t *lengths= drizzle_fetch_lengths(result);
+    uint32_t *lengths= drizzleclient_fetch_lengths(result);
     (void) tee_fputs("| ", PAGER);
-    drizzle_field_seek(result, 0);
-    for (uint off= 0; off < drizzle_num_fields(result); off++)
+    drizzleclient_field_seek(result, 0);
+    for (uint off= 0; off < drizzleclient_num_fields(result); off++)
     {
       const char *buffer;
       uint data_length;
@@ -2988,7 +2988,7 @@
         data_length= (uint) lengths[off];
       }
 
-      field= drizzle_fetch_field(result);
+      field= drizzleclient_fetch_field(result);
       field_max_length= field->max_length;
 
       /*
@@ -3065,13 +3065,13 @@
   DRIZZLE_FIELD *field;
   DRIZZLE_FIELD_OFFSET offset;
 
-  offset= drizzle_field_tell(result);
+  offset= drizzleclient_field_tell(result);
   assert(offset == 0);
 
-  while ((field= drizzle_fetch_field(result)) != NULL)
+  while ((field= drizzleclient_fetch_field(result)) != NULL)
     len+= get_field_disp_length(field) + 3; /* plus bar, space, & final space */
 
-  (void) drizzle_field_seek(result, offset);
+  (void) drizzleclient_field_seek(result, offset);
 
   return len + 1; /* plus final bar. */
 }
@@ -3113,7 +3113,7 @@
   uint    max_length=0;
   DRIZZLE_FIELD  *field;
 
-  while ((field = drizzle_fetch_field(result)))
+  while ((field = drizzleclient_fetch_field(result)))
   {
     uint length= field->name_length;
     if (length > max_length)
@@ -3121,17 +3121,17 @@
     field->max_length=length;
   }
 
-  drizzle_field_seek(result,0);
-  for (uint row_count=1; (cur= drizzle_fetch_row(result)); row_count++)
+  drizzleclient_field_seek(result,0);
+  for (uint row_count=1; (cur= drizzleclient_fetch_row(result)); row_count++)
   {
     if (interrupted_query)
       break;
-    drizzle_field_seek(result,0);
+    drizzleclient_field_seek(result,0);
     tee_fprintf(PAGER,
                 "*************************** %d. row ***************************\n", row_count);
-    for (uint off=0; off < drizzle_num_fields(result); off++)
+    for (uint off=0; off < drizzleclient_num_fields(result); off++)
     {
-      field= drizzle_fetch_field(result);
+      field= drizzleclient_fetch_field(result);
       tee_fprintf(PAGER, "%*s: ",(int) max_length,field->name);
       tee_fprintf(PAGER, "%s\n",cur[off] ? (char*) cur[off] : "NULL");
     }
@@ -3149,18 +3149,18 @@
   uint64_t num_rows;
 
   /* Save current error before calling "show warnings" */
-  uint error= drizzle_errno(&drizzle);
+  uint error= drizzleclient_errno(&drizzle);
 
   /* Get the warnings */
   query= "show warnings";
-  drizzle_real_query_for_lazy(query, strlen(query));
-  drizzle_store_result_for_lazy(&result);
+  drizzleclient_real_query_for_lazy(query, strlen(query));
+  drizzleclient_store_result_for_lazy(&result);
 
   /* Bail out when no warnings */
-  if (!(num_rows= drizzle_num_rows(result)))
+  if (!(num_rows= drizzleclient_num_rows(result)))
     goto end;
 
-  cur= drizzle_fetch_row(result);
+  cur= drizzleclient_fetch_row(result);
 
   /*
     Don't print a duplicate of the current error.  It is possible for SHOW
@@ -3176,11 +3176,11 @@
   do
   {
     tee_fprintf(PAGER, "%s (Code %s): %s\n", cur[0], cur[1], cur[2]);
-  } while ((cur= drizzle_fetch_row(result)));
+  } while ((cur= drizzleclient_fetch_row(result)));
   end_pager();
 
 end:
-  drizzle_free_result(result);
+  drizzleclient_free_result(result);
 }
 
 
@@ -3231,7 +3231,7 @@
   if (opt_silent < 2 && column_names)
   {
     int first=0;
-    while ((field = drizzle_fetch_field(result)))
+    while ((field = drizzleclient_fetch_field(result)))
     {
       if (first++)
         (void) tee_fputs("\t", PAGER);
@@ -3239,11 +3239,11 @@
     }
     (void) tee_fputs("\n", PAGER);
   }
-  while ((cur = drizzle_fetch_row(result)))
+  while ((cur = drizzleclient_fetch_row(result)))
   {
-    lengths= drizzle_fetch_lengths(result);
+    lengths= drizzleclient_fetch_lengths(result);
     safe_put_field(cur[0],lengths[0]);
-    for (uint off=1 ; off < drizzle_num_fields(result); off++)
+    for (uint off=1 ; off < drizzleclient_num_fields(result); off++)
     {
       (void) tee_fputs("\t", PAGER);
       safe_put_field(cur[off], lengths[off]);
@@ -3445,7 +3445,7 @@
 
   if (connected)
   {
-    sprintf(buff,"Connection id:    %u",drizzle_thread_id(&drizzle));
+    sprintf(buff,"Connection id:    %u",drizzleclient_thread_id(&drizzle));
     put_info(buff,INFO_INFO,0,0);
     sprintf(buff,"Current database: %.128s\n",
             current_db ? current_db : "*** NONE ***");
@@ -3570,22 +3570,22 @@
     if (one_database)
     {
       skip_updates= 1;
-      select_db= 0;    // don't do drizzle_select_db()
+      select_db= 0;    // don't do drizzleclient_select_db()
     }
     else
-      select_db= 2;    // do drizzle_select_db() and build_completion_hash()
+      select_db= 2;    // do drizzleclient_select_db() and build_completion_hash()
   }
   else
   {
     /*
       USE to the current db specified.
-      We do need to send drizzle_select_db() to make server
+      We do need to send drizzleclient_select_db() to make server
       update database level privileges, which might
       change since last USE (see bug#10979).
       For performance purposes, we'll skip rebuilding of completion hash.
     */
     skip_updates= 0;
-    select_db= 1;      // do only drizzle_select_db(), without completion
+    select_db= 1;      // do only drizzleclient_select_db(), without completion
   }
 
   if (select_db)
@@ -3596,14 +3596,14 @@
     */
     if (!connected && reconnect())
       return opt_reconnect ? -1 : 1;                        // Fatal error
-    if (drizzle_select_db(&drizzle,tmp))
+    if (drizzleclient_select_db(&drizzle,tmp))
     {
-      if (drizzle_errno(&drizzle) != CR_SERVER_GONE_ERROR)
+      if (drizzleclient_errno(&drizzle) != CR_SERVER_GONE_ERROR)
         return put_error(&drizzle);
 
       if (reconnect())
         return opt_reconnect ? -1 : 1;                      // Fatal error
-      if (drizzle_select_db(&drizzle,tmp))
+      if (drizzleclient_select_db(&drizzle,tmp))
         return put_error(&drizzle);
     }
     free(current_db);
@@ -3701,21 +3701,21 @@
   if (connected)
   {
     connected= 0;
-    drizzle_close(&drizzle);
+    drizzleclient_close(&drizzle);
   }
-  drizzle_create(&drizzle);
+  drizzleclient_create(&drizzle);
   if (opt_connect_timeout)
   {
     uint timeout=opt_connect_timeout;
-    drizzle_options(&drizzle,DRIZZLE_OPT_CONNECT_TIMEOUT,
+    drizzleclient_options(&drizzle,DRIZZLE_OPT_CONNECT_TIMEOUT,
                   (char*) &timeout);
   }
   if (opt_compress)
-    drizzle_options(&drizzle,DRIZZLE_OPT_COMPRESS,NULL);
+    drizzleclient_options(&drizzle,DRIZZLE_OPT_COMPRESS,NULL);
   if (opt_secure_auth)
-    drizzle_options(&drizzle, DRIZZLE_SECURE_AUTH, (char *) &opt_secure_auth);
+    drizzleclient_options(&drizzle, DRIZZLE_SECURE_AUTH, (char *) &opt_secure_auth);
   if (using_opt_local_infile)
-    drizzle_options(&drizzle,DRIZZLE_OPT_LOCAL_INFILE, (char*) &opt_local_infile);
+    drizzleclient_options(&drizzle,DRIZZLE_OPT_LOCAL_INFILE, (char*) &opt_local_infile);
   if (safe_updates)
   {
     char init_command[100];
@@ -3723,15 +3723,15 @@
             "SET SQL_SAFE_UPDATES=1,SQL_SELECT_LIMIT=%"PRIu32
             ",MAX_JOIN_SIZE=%"PRIu32,
             select_limit, max_join_size);
-    drizzle_options(&drizzle, DRIZZLE_INIT_COMMAND, init_command);
+    drizzleclient_options(&drizzle, DRIZZLE_INIT_COMMAND, init_command);
   }
-  if (!drizzle_connect(&drizzle, host, user, password,
+  if (!drizzleclient_connect(&drizzle, host, user, password,
                           database, opt_drizzle_port, opt_drizzle_unix_port,
                           connect_flag | CLIENT_MULTI_STATEMENTS))
   {
     if (!silent ||
-        (drizzle_errno(&drizzle) != CR_CONN_HOST_ERROR &&
-         drizzle_errno(&drizzle) != CR_CONNECTION_ERROR))
+        (drizzleclient_errno(&drizzle) != CR_CONN_HOST_ERROR &&
+         drizzleclient_errno(&drizzle) != CR_CONNECTION_ERROR))
     {
       (void) put_error(&drizzle);
       (void) fflush(stdout);
@@ -3757,21 +3757,21 @@
   usage(1);          /* Print version */
   if (connected)
   {
-    tee_fprintf(stdout, "\nConnection id:\t\t%lu\n",drizzle_thread_id(&drizzle));
+    tee_fprintf(stdout, "\nConnection id:\t\t%lu\n",drizzleclient_thread_id(&drizzle));
     /*
       Don't remove "limit 1",
       it is protection againts SQL_SELECT_LIMIT=0
     */
-    if (!drizzle_query(&drizzle,"select DATABASE(), USER() limit 1") &&
-        (result=drizzle_use_result(&drizzle)))
+    if (!drizzleclient_query(&drizzle,"select DATABASE(), USER() limit 1") &&
+        (result=drizzleclient_use_result(&drizzle)))
     {
-      DRIZZLE_ROW cur=drizzle_fetch_row(result);
+      DRIZZLE_ROW cur=drizzleclient_fetch_row(result);
       if (cur)
       {
         tee_fprintf(stdout, "Current database:\t%s\n", cur[0] ? cur[0] : "");
         tee_fprintf(stdout, "Current user:\t\t%s\n", cur[1]);
       }
-      drizzle_free_result(result);
+      drizzleclient_free_result(result);
     }
     tee_puts("SSL:\t\t\tNot in use", stdout);
   }
@@ -3792,16 +3792,16 @@
   tee_fprintf(stdout, "Using outfile:\t\t'%s'\n", opt_outfile ? outfile : "");
   tee_fprintf(stdout, "Using delimiter:\t%s\n", delimiter);
   tee_fprintf(stdout, "Server version:\t\t%s\n", server_version_string(&drizzle));
-  tee_fprintf(stdout, "Protocol version:\t%d\n", drizzle_get_proto_info(&drizzle));
-  tee_fprintf(stdout, "Connection:\t\t%s\n", drizzle_get_host_info(&drizzle));
-  if ((id= drizzle_insert_id(&drizzle)))
+  tee_fprintf(stdout, "Protocol version:\t%d\n", drizzleclient_get_proto_info(&drizzle));
+  tee_fprintf(stdout, "Connection:\t\t%s\n", drizzleclient_get_host_info(&drizzle));
+  if ((id= drizzleclient_insert_id(&drizzle)))
     tee_fprintf(stdout, "Insert id:\t\t%s\n", llstr(id, buff));
 
   /* "limit 1" is protection against SQL_SELECT_LIMIT=0 */
-  if (!drizzle_query(&drizzle,"select @@character_set_client, @@character_set_connection, @@character_set_server, @@character_set_database limit 1") &&
-      (result=drizzle_use_result(&drizzle)))
+  if (!drizzleclient_query(&drizzle,"select @@character_set_client, @@character_set_connection, @@character_set_server, @@character_set_database limit 1") &&
+      (result=drizzleclient_use_result(&drizzle)))
   {
-    DRIZZLE_ROW cur=drizzle_fetch_row(result);
+    DRIZZLE_ROW cur=drizzleclient_fetch_row(result);
     if (cur)
     {
       tee_fprintf(stdout, "Server characterset:\t%s\n", cur[2] ? cur[2] : "");
@@ -3809,10 +3809,10 @@
       tee_fprintf(stdout, "Client characterset:\t%s\n", cur[0] ? cur[0] : "");
       tee_fprintf(stdout, "Conn.  characterset:\t%s\n", cur[1] ? cur[1] : "");
     }
-    drizzle_free_result(result);
+    drizzleclient_free_result(result);
   }
 
-  if (strstr(drizzle_get_host_info(&drizzle),"TCP/IP") || ! drizzle.unix_socket)
+  if (strstr(drizzleclient_get_host_info(&drizzle),"TCP/IP") || ! drizzle.unix_socket)
     tee_fprintf(stdout, "TCP port:\t\t%d\n", drizzle.port);
   else
     tee_fprintf(stdout, "UNIX socket:\t\t%s\n", drizzle.unix_socket);
@@ -3851,19 +3851,19 @@
   {
     DRIZZLE_RES *result;
 
-    buf.append(drizzle_get_server_info(con));
+    buf.append(drizzleclient_get_server_info(con));
 
     /* "limit 1" is protection against SQL_SELECT_LIMIT=0 */
-    if (!drizzle_query(con, "select @@version_comment limit 1") &&
-        (result = drizzle_use_result(con)))
+    if (!drizzleclient_query(con, "select @@version_comment limit 1") &&
+        (result = drizzleclient_use_result(con)))
     {
-      DRIZZLE_ROW cur = drizzle_fetch_row(result);
+      DRIZZLE_ROW cur = drizzleclient_fetch_row(result);
       if (cur && cur[0])
       {
         buf.append(" ");
         buf.append(cur[0]);
       }
-      drizzle_free_result(result);
+      drizzleclient_free_result(result);
     }
   }
 
@@ -3945,8 +3945,8 @@
 static int
 put_error(DRIZZLE *con)
 {
-  return put_info(drizzle_error(con), INFO_ERROR, drizzle_errno(con),
-                  drizzle_sqlstate(con));
+  return put_info(drizzleclient_error(con), INFO_ERROR, drizzleclient_errno(con),
+                  drizzleclient_sqlstate(con));
 }
 
 
@@ -4111,7 +4111,7 @@
         break;
       case 'v':
         if (connected)
-          processed_prompt->append(drizzle_get_server_info(&drizzle));
+          processed_prompt->append(drizzleclient_get_server_info(&drizzle));
         else
           processed_prompt->append("not_connected");
         break;
@@ -4121,7 +4121,7 @@
       case 'h':
       {
         const char *prompt;
-        prompt= connected ? drizzle_get_host_info(&drizzle) : "not_connected";
+        prompt= connected ? drizzleclient_get_host_info(&drizzle) : "not_connected";
         if (strstr(prompt, "Localhost"))
           processed_prompt->append("localhost");
         else
@@ -4140,7 +4140,7 @@
           break;
         }
 
-        const char *host_info = drizzle_get_host_info(&drizzle);
+        const char *host_info = drizzleclient_get_host_info(&drizzle);
         if (strstr(host_info, "memory"))
         {
           processed_prompt->append(drizzle.host);
@@ -4268,13 +4268,13 @@
   free(part_username);
 
   DRIZZLE_RES *result;
-  if (!drizzle_query(&drizzle,"select USER()") &&
-      (result=drizzle_use_result(&drizzle)))
+  if (!drizzleclient_query(&drizzle,"select USER()") &&
+      (result=drizzleclient_use_result(&drizzle)))
   {
-    DRIZZLE_ROW cur=drizzle_fetch_row(result);
+    DRIZZLE_ROW cur=drizzleclient_fetch_row(result);
     full_username= strdup(cur[0]);
     part_username= strdup(strtok(cur[0],"@"));
-    (void) drizzle_fetch_row(result);        // Read eof
+    (void) drizzleclient_fetch_row(result);        // Read eof
   }
 }
 

=== modified file 'client/drizzleadmin.cc'
--- client/drizzleadmin.cc	2009-02-08 11:11:30 +0000
+++ client/drizzleadmin.cc	2009-02-08 11:28:58 +0000
@@ -200,7 +200,7 @@
   char **commands, **save_argv;
 
   MY_INIT(argv[0]);
-  drizzle_create(&drizzle);
+  drizzleclient_create(&drizzle);
   load_defaults("drizzle",load_default_groups,&argc,&argv);
   save_argv = argv;				/* Save for free_defaults */
   if ((ho_error=handle_options(&argc, &argv, my_long_options, get_one_option)))
@@ -225,12 +225,12 @@
   if (opt_connect_timeout)
   {
     uint tmp=opt_connect_timeout;
-    drizzle_options(&drizzle,DRIZZLE_OPT_CONNECT_TIMEOUT, (char*) &tmp);
+    drizzleclient_options(&drizzle,DRIZZLE_OPT_CONNECT_TIMEOUT, (char*) &tmp);
   }
 
   if (sql_connect(&drizzle, option_wait))
   {
-    unsigned int err= drizzle_errno(&drizzle);
+    unsigned int err= drizzleclient_errno(&drizzle);
     if (err >= CR_MIN_ERROR && err <= CR_MAX_ERROR)
       error= 1;
     else
@@ -249,7 +249,7 @@
   else
   {
     error=execute_commands(&drizzle,argc,commands);
-    drizzle_close(&drizzle);
+    drizzleclient_close(&drizzle);
   }
   free(opt_password);
   free(user);
@@ -269,7 +269,7 @@
 
   for (;;)
   {
-    if (drizzle_connect(drizzle,host,user,opt_password,NULL,tcp_port,NULL,0))
+    if (drizzleclient_connect(drizzle,host,user,opt_password,NULL,tcp_port,NULL,0))
     {
       drizzle->reconnect= 1;
       if (info)
@@ -288,26 +288,26 @@
           host= (char*) LOCAL_HOST;
 
         fprintf(stderr,_("connect to server at '%s' failed\nerror: '%s'"),
-                host, drizzle_error(drizzle));
+                host, drizzleclient_error(drizzle));
 
-        if (drizzle_errno(drizzle) == CR_CONN_HOST_ERROR ||
-          drizzle_errno(drizzle) == CR_UNKNOWN_HOST)
+        if (drizzleclient_errno(drizzle) == CR_CONN_HOST_ERROR ||
+          drizzleclient_errno(drizzle) == CR_UNKNOWN_HOST)
         {
           fprintf(stderr,_("Check that drizzled is running on %s"),host);
           fprintf(stderr,_(" and that the port is %d.\n"),
-          tcp_port ? tcp_port: drizzle_get_default_port());
+          tcp_port ? tcp_port: drizzleclient_get_default_port());
           fprintf(stderr,_("You can check this by doing 'telnet %s %d'\n"),
-                  host, tcp_port ? tcp_port: drizzle_get_default_port());
+                  host, tcp_port ? tcp_port: drizzleclient_get_default_port());
         }
       }
       return 1;
     }
     if (wait != UINT32_MAX)
       wait--;				/* One less retry */
-    if ((drizzle_errno(drizzle) != CR_CONN_HOST_ERROR) &&
-        (drizzle_errno(drizzle) != CR_CONNECTION_ERROR))
+    if ((drizzleclient_errno(drizzle) != CR_CONN_HOST_ERROR) &&
+        (drizzleclient_errno(drizzle) != CR_CONNECTION_ERROR))
     {
-      fprintf(stderr,_("Got error: %s\n"), drizzle_error(drizzle));
+      fprintf(stderr,_("Got error: %s\n"), drizzleclient_error(drizzle));
     }
     else if (!option_silent)
     {
@@ -349,13 +349,13 @@
       if (opt_verbose)
         printf(_("shutting down drizzled...\n"));
 
-      if (drizzle_shutdown(drizzle))
+      if (drizzleclient_shutdown(drizzle))
       {
         fprintf(stderr, _("shutdown failed; error: '%s'"),
-                drizzle_error(drizzle));
+                drizzleclient_error(drizzle));
         return -1;
       }
-      drizzle_close(drizzle);	/* Close connection to avoid error messages */
+      drizzleclient_close(drizzle);	/* Close connection to avoid error messages */
 
       if (opt_verbose)
         printf(_("done\n"));
@@ -365,23 +365,23 @@
     }
     case ADMIN_PING:
       drizzle->reconnect=0;	/* We want to know of reconnects */
-      if (!drizzle_ping(drizzle))
+      if (!drizzleclient_ping(drizzle))
       {
         if (option_silent < 2)
           puts(_("drizzled is alive"));
       }
       else
       {
-        if (drizzle_errno(drizzle) == CR_SERVER_GONE_ERROR)
+        if (drizzleclient_errno(drizzle) == CR_SERVER_GONE_ERROR)
         {
           drizzle->reconnect=1;
-          if (!drizzle_ping(drizzle))
+          if (!drizzleclient_ping(drizzle))
             puts(_("connection was down, but drizzled is now alive"));
         }
         else
 	      {
           fprintf(stderr,_("drizzled doesn't answer to ping, error: '%s'"),
-                  drizzle_error(drizzle));
+                  drizzleclient_error(drizzle));
           return -1;
         }
       }
@@ -399,7 +399,7 @@
 static void print_version(void)
 {
   printf(_("%s  Ver %s Distrib %s, for %s on %s\n"),my_progname,ADMIN_VERSION,
-	 drizzle_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+	 drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 static void usage(void)

=== modified file 'client/drizzlecheck.cc'
--- client/drizzlecheck.cc	2009-02-08 11:11:30 +0000
+++ client/drizzlecheck.cc	2009-02-08 11:28:58 +0000
@@ -35,7 +35,7 @@
 #define EX_USAGE 1
 #define EX_MYSQLERR 2
 
-static DRIZZLE drizzle_connection, *sock= 0;
+static DRIZZLE drizzleclient_connection, *sock= 0;
 static bool opt_alldbs= false, opt_check_only_changed= false,
             opt_extended= false, opt_compress= false, opt_databases= false,
             opt_fast= false, opt_medium_check= false, opt_quick= false,
@@ -193,7 +193,7 @@
 static void print_version(void)
 {
   printf("%s  Ver %s Distrib %s, for %s (%s)\n", my_progname, CHECK_VERSION,
-   drizzle_get_client_info(), SYSTEM_TYPE, MACHINE_TYPE);
+   drizzleclient_get_client_info(), SYSTEM_TYPE, MACHINE_TYPE);
 } /* print_version */
 
 static void usage(void)
@@ -396,14 +396,14 @@
   DRIZZLE_RES *tableres;
   int result = 0;
 
-  if (drizzle_query(sock, "SHOW DATABASES") ||
-      !(tableres = drizzle_store_result(sock)))
+  if (drizzleclient_query(sock, "SHOW DATABASES") ||
+      !(tableres = drizzleclient_store_result(sock)))
   {
     my_printf_error(0, "Error: Couldn't execute 'SHOW DATABASES': %s",
-        MYF(0), drizzle_error(sock));
+        MYF(0), drizzleclient_error(sock));
     return 1;
   }
-  while ((row = drizzle_fetch_row(tableres)))
+  while ((row = drizzleclient_fetch_row(tableres)))
   {
     if (process_one_db(row[0]))
       result = 1;
@@ -510,11 +510,11 @@
 
   if (use_db(database))
     return 1;
-  if (drizzle_query(sock, "SHOW /*!50002 FULL*/ TABLES") ||
-  !((res= drizzle_store_result(sock))))
+  if (drizzleclient_query(sock, "SHOW /*!50002 FULL*/ TABLES") ||
+  !((res= drizzleclient_store_result(sock))))
     return 1;
 
-  num_columns= drizzle_num_fields(res);
+  num_columns= drizzleclient_num_fields(res);
 
   if (opt_all_in_1)
   {
@@ -527,16 +527,16 @@
     char *tables, *end;
     uint tot_length = 0;
 
-    while ((row = drizzle_fetch_row(res)))
+    while ((row = drizzleclient_fetch_row(res)))
       tot_length+= fixed_name_length(row[0]) + 2;
-    drizzle_data_seek(res, 0);
+    drizzleclient_data_seek(res, 0);
 
     if (!(tables=(char *) malloc(sizeof(char)*tot_length+4)))
     {
-      drizzle_free_result(res);
+      drizzleclient_free_result(res);
       return 1;
     }
-    for (end = tables + 1; (row = drizzle_fetch_row(res)) ;)
+    for (end = tables + 1; (row = drizzleclient_fetch_row(res)) ;)
     {
       if ((num_columns == 2) && (strcmp(row[1], "VIEW") == 0))
         continue;
@@ -551,7 +551,7 @@
   }
   else
   {
-    while ((row = drizzle_fetch_row(res)))
+    while ((row = drizzleclient_fetch_row(res)))
     {
       /* Skip views if we don't perform renaming. */
       if ((what_to_do != DO_UPGRADE) && (num_columns == 2) && (strcmp(row[1], "VIEW") == 0))
@@ -560,7 +560,7 @@
       handle_request_for_tables(row[0], fixed_name_length(row[0]));
     }
   }
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
   return 0;
 } /* process_all_tables_in_db */
 
@@ -573,10 +573,10 @@
   if (strncmp(name, "#mysql50#", 9))
     return 1;
   sprintf(qbuf, "RENAME TABLE `%s` TO `%s`", name, name + 9);
-  if (drizzle_query(sock, qbuf))
+  if (drizzleclient_query(sock, qbuf))
   {
     fprintf(stderr, "Failed to %s\n", qbuf);
-    fprintf(stderr, "Error: %s\n", drizzle_error(sock));
+    fprintf(stderr, "Error: %s\n", drizzleclient_error(sock));
     rc= 1;
   }
   if (verbose)
@@ -591,10 +591,10 @@
   if (strncmp(name, "#mysql50#", 9))
     return 1;
   sprintf(qbuf, "ALTER DATABASE `%s` UPGRADE DATA DIRECTORY NAME", name);
-  if (drizzle_query(sock, qbuf))
+  if (drizzleclient_query(sock, qbuf))
   {
     fprintf(stderr, "Failed to %s\n", qbuf);
-    fprintf(stderr, "Error: %s\n", drizzle_error(sock));
+    fprintf(stderr, "Error: %s\n", drizzleclient_error(sock));
     rc= 1;
   }
   if (verbose)
@@ -621,10 +621,10 @@
 
 static int use_db(char *database)
 {
-  if (drizzle_get_server_version(sock) >= 50003 &&
+  if (drizzleclient_get_server_version(sock) >= 50003 &&
       !my_strcasecmp(&my_charset_utf8_general_ci, database, "information_schema"))
     return 1;
-  if (drizzle_select_db(sock, database))
+  if (drizzleclient_select_db(sock, database))
   {
     DBerror(sock, "when selecting the database");
     return 1;
@@ -684,7 +684,7 @@
     ptr+= sprintf(ptr," %s",options);
     query_length= (uint) (ptr - query);
   }
-  if (drizzle_real_query(sock, query, query_length))
+  if (drizzleclient_real_query(sock, query, query_length))
   {
     sprintf(message, "when executing '%s TABLE ... %s'", op, options);
     DBerror(sock, message);
@@ -704,10 +704,10 @@
   uint i;
   bool found_error=0;
 
-  res = drizzle_use_result(sock);
+  res = drizzleclient_use_result(sock);
 
   prev[0] = '\0';
-  for (i = 0; (row = drizzle_fetch_row(res)); i++)
+  for (i = 0; (row = drizzleclient_fetch_row(res)); i++)
   {
     int changed = strcmp(prev, row[0]);
     bool status = !strcmp(row[2], "status");
@@ -742,7 +742,7 @@
   /* add the last table to be repaired to the list */
   if (found_error && opt_auto_repair && what_to_do != DO_REPAIR)
     tables4repair.push_back(string(prev));
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
 }
 
 
@@ -753,18 +753,18 @@
   {
     fprintf(stderr, "# Connecting to %s...\n", host ? host : "localhost");
   }
-  drizzle_create(&drizzle_connection);
+  drizzleclient_create(&drizzleclient_connection);
   if (opt_compress)
-    drizzle_options(&drizzle_connection, DRIZZLE_OPT_COMPRESS, NULL);
+    drizzleclient_options(&drizzleclient_connection, DRIZZLE_OPT_COMPRESS, NULL);
   if (opt_protocol)
-    drizzle_options(&drizzle_connection,DRIZZLE_OPT_PROTOCOL,(char*)&opt_protocol);
-  if (!(sock = drizzle_connect(&drizzle_connection, host, user, passwd,
+    drizzleclient_options(&drizzleclient_connection,DRIZZLE_OPT_PROTOCOL,(char*)&opt_protocol);
+  if (!(sock = drizzleclient_connect(&drizzleclient_connection, host, user, passwd,
          NULL, opt_drizzle_port, opt_drizzle_unix_port, 0)))
   {
-    DBerror(&drizzle_connection, "when trying to connect");
+    DBerror(&drizzleclient_connection, "when trying to connect");
     return 1;
   }
-  drizzle_connection.reconnect= 1;
+  drizzleclient_connection.reconnect= 1;
   return 0;
 } /* dbConnect */
 
@@ -773,14 +773,14 @@
 {
   if (verbose)
     fprintf(stderr, "# Disconnecting from %s...\n", host ? host : "localhost");
-  drizzle_close(sock);
+  drizzleclient_close(sock);
 } /* dbDisconnect */
 
 
 static void DBerror(DRIZZLE *drizzle, const char *when)
 {
   my_printf_error(0,"Got error: %d: %s %s", MYF(0),
-      drizzle_errno(drizzle), drizzle_error(drizzle), when);
+      drizzleclient_errno(drizzle), drizzleclient_error(drizzle), when);
   safe_exit(EX_MYSQLERR);
   return;
 } /* DBerror */
@@ -793,7 +793,7 @@
   if (ignore_errors)
     return;
   if (sock)
-    drizzle_close(sock);
+    drizzleclient_close(sock);
   exit(error);
 }
 

=== modified file 'client/drizzledump.cc'
--- client/drizzledump.cc	2009-02-08 11:11:30 +0000
+++ client/drizzledump.cc	2009-02-08 11:28:58 +0000
@@ -96,7 +96,7 @@
 static bool debug_info_flag= false, debug_check_flag= false;
 static uint32_t opt_max_allowed_packet, opt_net_buffer_length, show_progress_size= 0;
 static uint64_t total_rows= 0;
-static DRIZZLE drizzle_connection, *drizzle= 0;
+static DRIZZLE drizzleclient_connection, *drizzle= 0;
 static string insert_pat;
 static char  *opt_password= NULL, *current_user= NULL,
              *current_host= NULL, *path= NULL, *fields_terminated= NULL,
@@ -472,7 +472,7 @@
 static void print_version(void)
 {
   printf(_("%s  Ver %s Distrib %s, for %s (%s)\n"),my_progname,DUMP_VERSION,
-         drizzle_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+         drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
 } /* print_version */
 
 
@@ -525,7 +525,7 @@
     {
       fprintf(sql_file,
               "-- DRIZZLE dump %s  Distrib %s, for %s (%s)\n--\n",
-              DUMP_VERSION, drizzle_get_client_info(),
+              DUMP_VERSION, drizzleclient_get_client_info(),
               SYSTEM_TYPE, MACHINE_TYPE);
       fprintf(sql_file, "-- Host: %s    Database: %s\n",
               current_host ? current_host : "localhost", db_name ? db_name :
@@ -533,7 +533,7 @@
       fputs("-- ------------------------------------------------------\n",
             sql_file);
       fprintf(sql_file, "-- Server version\t%s\n",
-              drizzle_get_server_info(&drizzle_connection));
+              drizzleclient_get_server_info(&drizzleclient_connection));
     }
     if (opt_set_charset)
       fprintf(sql_file,
@@ -774,7 +774,7 @@
 static int get_options(int *argc, char ***argv)
 {
   int ho_error;
-  const DRIZZLE_PARAMETERS *drizzle_params= drizzle_get_parameters();
+  const DRIZZLE_PARAMETERS *drizzle_params= drizzleclient_get_parameters();
 
   opt_max_allowed_packet= *drizzle_params->p_max_allowed_packet;
   opt_net_buffer_length= *drizzle_params->p_net_buffer_length;
@@ -866,7 +866,7 @@
 {
 
   maybe_die(EX_DRIZZLEERR, _("Got error: %d: %s %s"),
-          drizzle_errno(drizzle_arg), drizzle_error(drizzle_arg), when);
+          drizzleclient_errno(drizzle_arg), drizzleclient_error(drizzle_arg), when);
   return;
 }
 
@@ -940,10 +940,10 @@
   some.
 
   SYNOPSIS
-    drizzle_query_with_error_report()
+    drizzleclient_query_with_error_report()
     drizzle_con       connection to use
     res             if non zero, result will be put there with
-                    drizzle_store_result()
+                    drizzleclient_store_result()
     query           query to send to server
 
   RETURN VALUES
@@ -951,14 +951,14 @@
     1               error
 */
 
-static int drizzle_query_with_error_report(DRIZZLE *drizzle_con, DRIZZLE_RES **res,
+static int drizzleclient_query_with_error_report(DRIZZLE *drizzle_con, DRIZZLE_RES **res,
                                          const char *query)
 {
-  if (drizzle_query(drizzle_con, query) ||
-      (res && !((*res)= drizzle_store_result(drizzle_con))))
+  if (drizzleclient_query(drizzle_con, query) ||
+      (res && !((*res)= drizzleclient_store_result(drizzle_con))))
   {
     maybe_die(EX_DRIZZLEERR, _("Couldn't execute '%s': %s (%d)"),
-            query, drizzle_error(drizzle_con), drizzle_errno(drizzle_con));
+            query, drizzleclient_error(drizzle_con), drizzleclient_errno(drizzle_con));
     return 1;
   }
   return 0;
@@ -1006,7 +1006,7 @@
   if (ignore_errors)
     return;
   if (drizzle)
-    drizzle_close(drizzle);
+    drizzleclient_close(drizzle);
   free_resources();
   exit(error);
 }
@@ -1019,14 +1019,14 @@
 static int connect_to_db(char *host, char *user,char *passwd)
 {
   verbose_msg(_("-- Connecting to %s...\n"), host ? host : "localhost");
-  drizzle_create(&drizzle_connection);
+  drizzleclient_create(&drizzleclient_connection);
   if (opt_compress)
-    drizzle_options(&drizzle_connection,DRIZZLE_OPT_COMPRESS,NULL);
-  if (!(drizzle= drizzle_connect(&drizzle_connection,host,user,passwd,
+    drizzleclient_options(&drizzleclient_connection,DRIZZLE_OPT_COMPRESS,NULL);
+  if (!(drizzle= drizzleclient_connect(&drizzleclient_connection,host,user,passwd,
                                   NULL,opt_drizzle_port, NULL,
                                   0)))
   {
-    DB_error(&drizzle_connection, "when trying to connect");
+    DB_error(&drizzleclient_connection, "when trying to connect");
     return(1);
   }
 
@@ -1040,7 +1040,7 @@
 static void dbDisconnect(char *host)
 {
   verbose_msg(_("-- Disconnecting from %s...\n"), host ? host : "localhost");
-  drizzle_close(drizzle);
+  drizzleclient_close(drizzle);
 } /* dbDisconnect */
 
 
@@ -1051,7 +1051,7 @@
   if (!(tmp=(char*) malloc(length*2+1)))
     die(EX_DRIZZLEERR, _("Couldn't allocate memory"));
 
-  drizzle_escape_string(tmp, pos, length);
+  drizzleclient_escape_string(tmp, pos, length);
   fputc('\'', file);
   fputs(tmp, file);
   fputc('\'', file);
@@ -1312,12 +1312,12 @@
 {
   uint i;
   DRIZZLE_FIELD *field;
-  uint32_t *lengths= drizzle_fetch_lengths(tableRes);
+  uint32_t *lengths= drizzleclient_fetch_lengths(tableRes);
 
   fprintf(xml_file, "\t\t<%s", row_name);
   check_io(xml_file);
-  drizzle_field_seek(tableRes, 0);
-  for (i= 0; (field= drizzle_fetch_field(tableRes)); i++)
+  drizzleclient_field_seek(tableRes, 0);
+  for (i= 0; (field= drizzleclient_fetch_field(tableRes)); i++)
   {
     if ((*row)[i])
     {
@@ -1426,7 +1426,7 @@
 
       snprintf(buff, sizeof(buff), "show create table %s", result_table);
 
-      if (drizzle_query_with_error_report(drizzle, &result, buff))
+      if (drizzleclient_query_with_error_report(drizzle, &result, buff))
         return false;
 
       if (path)
@@ -1451,18 +1451,18 @@
         check_io(sql_file);
       }
 
-      field= drizzle_fetch_field_direct(result, 0);
+      field= drizzleclient_fetch_field_direct(result, 0);
 
-      row= drizzle_fetch_row(result);
+      row= drizzleclient_fetch_row(result);
 
       fprintf(sql_file, "%s;\n", row[1]);
 
       check_io(sql_file);
-      drizzle_free_result(result);
+      drizzleclient_free_result(result);
     }
     snprintf(query_buff, sizeof(query_buff), "show fields from %s",
              result_table);
-    if (drizzle_query_with_error_report(drizzle, &result, query_buff))
+    if (drizzleclient_query_with_error_report(drizzle, &result, query_buff))
     {
       if (path)
         my_fclose(sql_file, MYF(MY_WME));
@@ -1496,7 +1496,7 @@
       }
     }
 
-    while ((row= drizzle_fetch_row(result)))
+    while ((row= drizzleclient_fetch_row(result)))
     {
       if (complete_insert)
       {
@@ -1508,17 +1508,17 @@
         insert_pat.append(quote_name(row[SHOW_FIELDNAME], name_buff, 0));
       }
     }
-    *num_fields= drizzle_num_rows(result);
-    drizzle_free_result(result);
+    *num_fields= drizzleclient_num_rows(result);
+    drizzleclient_free_result(result);
   }
   else
   {
     verbose_msg(_("%s: Warning: Can't set SQL_QUOTE_SHOW_CREATE option (%s)\n"),
-                my_progname, drizzle_error(drizzle));
+                my_progname, drizzleclient_error(drizzle));
 
     snprintf(query_buff, sizeof(query_buff), "show fields from %s",
              result_table);
-    if (drizzle_query_with_error_report(drizzle, &result, query_buff))
+    if (drizzleclient_query_with_error_report(drizzle, &result, query_buff))
       return false;
 
     /* Make an sql-file, if path was given iow. option -T was given */
@@ -1562,9 +1562,9 @@
       }
     }
 
-    while ((row= drizzle_fetch_row(result)))
+    while ((row= drizzleclient_fetch_row(result)))
     {
-      uint32_t *lengths= drizzle_fetch_lengths(result);
+      uint32_t *lengths= drizzleclient_fetch_lengths(result);
       if (init)
       {
         if (!opt_xml && !opt_no_create_info)
@@ -1606,24 +1606,24 @@
         check_io(sql_file);
       }
     }
-    *num_fields= drizzle_num_rows(result);
-    drizzle_free_result(result);
+    *num_fields= drizzleclient_num_rows(result);
+    drizzleclient_free_result(result);
     if (!opt_no_create_info)
     {
       /* Make an sql-file, if path was given iow. option -T was given */
       char buff[20+FN_REFLEN];
       uint keynr,primary_key;
       snprintf(buff, sizeof(buff), "show keys from %s", result_table);
-      if (drizzle_query_with_error_report(drizzle, &result, buff))
+      if (drizzleclient_query_with_error_report(drizzle, &result, buff))
       {
-        if (drizzle_errno(drizzle) == ER_WRONG_OBJECT)
+        if (drizzleclient_errno(drizzle) == ER_WRONG_OBJECT)
         {
           /* it is VIEW */
           fputs("\t\t<options Comment=\"view\" />\n", sql_file);
           goto continue_xml;
         }
         fprintf(stderr, _("%s: Can't get keys for table %s (%s)\n"),
-                my_progname, result_table, drizzle_error(drizzle));
+                my_progname, result_table, drizzleclient_error(drizzle));
         if (path)
           my_fclose(sql_file, MYF(MY_WME));
         return false;
@@ -1632,7 +1632,7 @@
       /* Find first which key is primary key */
       keynr=0;
       primary_key=INT_MAX;
-      while ((row= drizzle_fetch_row(result)))
+      while ((row= drizzleclient_fetch_row(result)))
       {
         if (atoi(row[3]) == 1)
         {
@@ -1648,9 +1648,9 @@
           }
         }
       }
-      drizzle_data_seek(result,0);
+      drizzleclient_data_seek(result,0);
       keynr=0;
-      while ((row= drizzle_fetch_row(result)))
+      while ((row= drizzleclient_fetch_row(result)))
       {
         if (opt_xml)
         {
@@ -1678,7 +1678,7 @@
           fprintf(sql_file, " (%s)",row[7]);      /* Sub key */
         check_io(sql_file);
       }
-      drizzle_free_result(result);
+      drizzleclient_free_result(result);
       if (!opt_xml)
       {
         if (keynr)
@@ -1695,19 +1695,19 @@
         snprintf(buff, sizeof(buff), "show table status like %s",
                  quote_for_like(table, show_name_buff));
 
-        if (drizzle_query_with_error_report(drizzle, &result, buff))
+        if (drizzleclient_query_with_error_report(drizzle, &result, buff))
         {
-          if (drizzle_errno(drizzle) != ER_PARSE_ERROR)
+          if (drizzleclient_errno(drizzle) != ER_PARSE_ERROR)
           {                                     /* If old DRIZZLE version */
             verbose_msg(_("-- Warning: Couldn't get status information for " \
-                        "table %s (%s)\n"), result_table,drizzle_error(drizzle));
+                        "table %s (%s)\n"), result_table,drizzleclient_error(drizzle));
           }
         }
-        else if (!(row= drizzle_fetch_row(result)))
+        else if (!(row= drizzleclient_fetch_row(result)))
         {
           fprintf(stderr,
                   _("Error: Couldn't read status information for table %s (%s)\n"),
-                  result_table,drizzle_error(drizzle));
+                  result_table,drizzleclient_error(drizzle));
         }
         else
         {
@@ -1724,7 +1724,7 @@
             check_io(sql_file);
           }
         }
-        drizzle_free_result(result);              /* Is always safe to free */
+        drizzleclient_free_result(result);              /* Is always safe to free */
       }
 continue_xml:
       if (!opt_xml)
@@ -1931,7 +1931,7 @@
       query_string.append( order_by);
     }
 
-    if (drizzle_real_query(drizzle, query_string.c_str(), query_string.length()))
+    if (drizzleclient_real_query(drizzle, query_string.c_str(), query_string.length()))
     {
       DB_error(drizzle, _("when executing 'SELECT INTO OUTFILE'"));
       return;
@@ -1976,15 +1976,15 @@
       fputs("\n", md_result_file);
       check_io(md_result_file);
     }
-    if (drizzle_query_with_error_report(drizzle, 0, query_string.c_str()))
+    if (drizzleclient_query_with_error_report(drizzle, 0, query_string.c_str()))
     {
       DB_error(drizzle, _("when retrieving data from server"));
       goto err;
     }
     if (quick)
-      res=drizzle_use_result(drizzle);
+      res=drizzleclient_use_result(drizzle);
     else
-      res=drizzle_store_result(drizzle);
+      res=drizzleclient_store_result(drizzle);
     if (!res)
     {
       DB_error(drizzle, _("when retrieving data from server"));
@@ -1992,7 +1992,7 @@
     }
 
     verbose_msg(_("-- Retrieving rows...\n"));
-    if (drizzle_num_fields(res) != num_fields)
+    if (drizzleclient_num_fields(res) != num_fields)
     {
       fprintf(stderr,_("%s: Error in field count for table: %s !  Aborting.\n"),
               my_progname, result_table);
@@ -2026,10 +2026,10 @@
       check_io(md_result_file);
     }
 
-    while ((row= drizzle_fetch_row(res)))
+    while ((row= drizzleclient_fetch_row(res)))
     {
       uint i;
-      uint32_t *lengths= drizzle_fetch_lengths(res);
+      uint32_t *lengths= drizzleclient_fetch_lengths(res);
       rownr++;
       if ((rownr % show_progress_size) == 0)
       {
@@ -2040,7 +2040,7 @@
         fputs(insert_pat.c_str(),md_result_file);
         check_io(md_result_file);
       }
-      drizzle_field_seek(res,0);
+      drizzleclient_field_seek(res,0);
 
       if (opt_xml)
       {
@@ -2048,12 +2048,12 @@
         check_io(md_result_file);
       }
 
-      for (i= 0; i < drizzle_num_fields(res); i++)
+      for (i= 0; i < drizzleclient_num_fields(res); i++)
       {
         int is_blob;
         uint32_t length= lengths[i];
 
-        if (!(field= drizzle_fetch_field(res)))
+        if (!(field= drizzleclient_fetch_field(res)))
           die(EX_CONSCHECK,
                       _("Not enough fields from table %s! Aborting.\n"),
                       result_table);
@@ -2101,7 +2101,7 @@
                 else
                 {
                   extended_row.append("'");
-                  drizzle_escape_string(tmp_str,
+                  drizzleclient_escape_string(tmp_str,
                                         row[i],length);
                   extended_row.append(tmp_str);
                   extended_row.append("'");
@@ -2238,13 +2238,13 @@
       fputs(";\n", md_result_file);             /* If not empty table */
     fflush(md_result_file);
     check_io(md_result_file);
-    if (drizzle_errno(drizzle))
+    if (drizzleclient_errno(drizzle))
     {
       snprintf(buf, sizeof(buf),
                _("%s: Error %d: %s when dumping table %s at row: %d\n"),
                my_progname,
-               drizzle_errno(drizzle),
-               drizzle_error(drizzle),
+               drizzleclient_errno(drizzle),
+               drizzleclient_error(drizzle),
                result_table,
                rownr);
       fputs(buf,stderr);
@@ -2269,7 +2269,7 @@
       fprintf(md_result_file, "commit;\n");
       check_io(md_result_file);
     }
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
   }
   return;
 
@@ -2286,17 +2286,17 @@
 
   if (!res)
   {
-    if (!(res= drizzle_list_tables(drizzle,NULL)))
+    if (!(res= drizzleclient_list_tables(drizzle,NULL)))
       return(NULL);
   }
-  if ((row= drizzle_fetch_row(res)))
+  if ((row= drizzleclient_fetch_row(res)))
     return((char*) row[0]);
 
   if (reset)
-    drizzle_data_seek(res,0);      /* We want to read again */
+    drizzleclient_data_seek(res,0);      /* We want to read again */
   else
   {
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
     res= NULL;
   }
   return(NULL);
@@ -2309,9 +2309,9 @@
   DRIZZLE_RES *tableres;
   int result=0;
 
-  if (drizzle_query_with_error_report(drizzle, &tableres, "SHOW DATABASES"))
+  if (drizzleclient_query_with_error_report(drizzle, &tableres, "SHOW DATABASES"))
     return 1;
-  while ((row= drizzle_fetch_row(tableres)))
+  while ((row= drizzleclient_fetch_row(tableres)))
   {
     if (dump_all_tables_in_db(row[0]))
       result=1;
@@ -2362,7 +2362,7 @@
              "SHOW CREATE DATABASE IF NOT EXISTS %s",
              qdatabase);
 
-    if (drizzle_query(drizzle, qbuf) || !(dbinfo = drizzle_store_result(drizzle)))
+    if (drizzleclient_query(drizzle, qbuf) || !(dbinfo = drizzleclient_store_result(drizzle)))
     {
       /* Old server version, dump generic CREATE DATABASE */
       if (opt_drop_database)
@@ -2379,12 +2379,12 @@
         fprintf(md_result_file,
                 "\nDROP DATABASE IF EXISTS %s;\n",
                 qdatabase);
-      row = drizzle_fetch_row(dbinfo);
+      row = drizzleclient_fetch_row(dbinfo);
       if (row[1])
       {
         fprintf(md_result_file,"\n%s;\n",row[1]);
       }
-      drizzle_free_result(dbinfo);
+      drizzleclient_free_result(dbinfo);
     }
   }
   return(0);
@@ -2393,11 +2393,11 @@
 
 static int init_dumping(char *database, int init_func(char*))
 {
-  if (drizzle_get_server_version(drizzle) >= 50003 &&
+  if (drizzleclient_get_server_version(drizzle) >= 50003 &&
       !my_strcasecmp(&my_charset_utf8_general_ci, database, "information_schema"))
     return 1;
 
-  if (drizzle_select_db(drizzle, database))
+  if (drizzleclient_select_db(drizzle, database))
   {
     DB_error(drizzle, _("when selecting the database"));
     return 1;                   /* If --force */
@@ -2466,14 +2466,14 @@
         query.append( " READ LOCAL,");
       }
     }
-    if (numrows && drizzle_real_query(drizzle, query.c_str(), query.length()-1))
+    if (numrows && drizzleclient_real_query(drizzle, query.c_str(), query.length()-1))
       DB_error(drizzle, _("when using LOCK TABLES"));
             /* We shall continue here, if --force was given */
     query.clear();
   }
   if (flush_logs)
   {
-    if (drizzle_refresh(drizzle, REFRESH_LOG))
+    if (drizzleclient_refresh(drizzle, REFRESH_LOG))
       DB_error(drizzle, _("when doing refresh"));
            /* We shall continue here, if --force was given */
   }
@@ -2493,7 +2493,7 @@
     check_io(md_result_file);
   }
   if (lock_tables)
-    drizzle_query_with_error_report(drizzle, 0, "UNLOCK TABLES");
+    drizzleclient_query_with_error_report(drizzle, 0, "UNLOCK TABLES");
 
   return(0);
 } /* dump_all_tables_in_db */
@@ -2524,12 +2524,12 @@
   snprintf(query, sizeof(query), "SHOW TABLES LIKE %s",
            quote_for_like(old_table_name, show_name_buff));
 
-  if (drizzle_query_with_error_report(drizzle, 0, query))
+  if (drizzleclient_query_with_error_report(drizzle, 0, query))
     return NULL;
 
-  if ((table_res= drizzle_store_result(drizzle)))
+  if ((table_res= drizzleclient_store_result(drizzle)))
   {
-    uint64_t num_rows= drizzle_num_rows(table_res);
+    uint64_t num_rows= drizzleclient_num_rows(table_res);
     if (num_rows > 0)
     {
       uint32_t *lengths;
@@ -2537,11 +2537,11 @@
         Return first row
         TODO: Return all matching rows
       */
-      row= drizzle_fetch_row(table_res);
-      lengths= drizzle_fetch_lengths(table_res);
+      row= drizzleclient_fetch_row(table_res);
+      lengths= drizzleclient_fetch_lengths(table_res);
       name= strmake_root(root, row[0], lengths[0]);
     }
-    drizzle_free_result(table_res);
+    drizzleclient_free_result(table_res);
   }
   return(name);
 }
@@ -2589,7 +2589,7 @@
 
   if (lock_tables)
   {
-    if (drizzle_real_query(drizzle, lock_tables_query.c_str(),
+    if (drizzleclient_real_query(drizzle, lock_tables_query.c_str(),
                          lock_tables_query.length()-1))
     {
       if (!ignore_errors)
@@ -2602,7 +2602,7 @@
   }
   if (flush_logs)
   {
-    if (drizzle_refresh(drizzle, REFRESH_LOG))
+    if (drizzleclient_refresh(drizzle, REFRESH_LOG))
     {
       if (!ignore_errors)
         free_root(&root, MYF(0));
@@ -2626,7 +2626,7 @@
     check_io(md_result_file);
   }
   if (lock_tables)
-    drizzle_query_with_error_report(drizzle, 0, "UNLOCK TABLES");
+    drizzleclient_query_with_error_report(drizzle, 0, "UNLOCK TABLES");
   return(0);
 } /* dump_selected_tables */
 
@@ -2637,13 +2637,13 @@
   DRIZZLE_RES *master;
   const char *comment_prefix=
     (opt_master_data == DRIZZLE_OPT_MASTER_DATA_COMMENTED_SQL) ? "-- " : "";
-  if (drizzle_query_with_error_report(drizzle_con, &master, "SHOW MASTER STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &master, "SHOW MASTER STATUS"))
   {
     return 1;
   }
   else
   {
-    row= drizzle_fetch_row(master);
+    row= drizzleclient_fetch_row(master);
     if (row && row[0] && row[1])
     {
       /* SHOW MASTER STATUS reports file and position */
@@ -2661,11 +2661,11 @@
       /* SHOW MASTER STATUS reports nothing and --force is not enabled */
       my_printf_error(0, _("Error: Binlogging on server not active"),
                       MYF(0));
-      drizzle_free_result(master);
+      drizzleclient_free_result(master);
       maybe_exit(EX_DRIZZLEERR);
       return 1;
     }
-    drizzle_free_result(master);
+    drizzleclient_free_result(master);
   }
   return 0;
 }
@@ -2674,26 +2674,26 @@
 {
   DRIZZLE_RES *slave;
   /* We need to check if the slave sql is running in the first place */
-  if (drizzle_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
     return(1);
   else
   {
-    DRIZZLE_ROW row= drizzle_fetch_row(slave);
+    DRIZZLE_ROW row= drizzleclient_fetch_row(slave);
     if (row && row[11])
     {
       /* if SLAVE SQL is not running, we don't stop it */
       if (!strcmp(row[11],"No"))
       {
-        drizzle_free_result(slave);
+        drizzleclient_free_result(slave);
         /* Silently assume that they don't have the slave running */
         return(0);
       }
     }
   }
-  drizzle_free_result(slave);
+  drizzleclient_free_result(slave);
 
   /* now, stop slave if running */
-  if (drizzle_query_with_error_report(drizzle_con, 0, "STOP SLAVE SQL_THREAD"))
+  if (drizzleclient_query_with_error_report(drizzle_con, 0, "STOP SLAVE SQL_THREAD"))
     return(1);
 
   return(0);
@@ -2722,7 +2722,7 @@
   DRIZZLE_RES *slave;
   const char *comment_prefix=
     (opt_slave_data == DRIZZLE_OPT_SLAVE_DATA_COMMENTED_SQL) ? "-- " : "";
-  if (drizzle_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
   {
     if (!ignore_errors)
     {
@@ -2733,7 +2733,7 @@
   }
   else
   {
-    DRIZZLE_ROW row= drizzle_fetch_row(slave);
+    DRIZZLE_ROW row= drizzleclient_fetch_row(slave);
     if (row && row[9] && row[21])
     {
       /* SHOW MASTER STATUS reports file and position */
@@ -2756,7 +2756,7 @@
 
       check_io(md_result_file);
     }
-    drizzle_free_result(slave);
+    drizzleclient_free_result(slave);
   }
   return 0;
 }
@@ -2765,26 +2765,26 @@
 {
   DRIZZLE_RES *slave;
   /* We need to check if the slave sql is stopped in the first place */
-  if (drizzle_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
     return(1);
   else
   {
-    DRIZZLE_ROW row= drizzle_fetch_row(slave);
+    DRIZZLE_ROW row= drizzleclient_fetch_row(slave);
     if (row && row[11])
     {
       /* if SLAVE SQL is not running, we don't start it */
       if (!strcmp(row[11],"Yes"))
       {
-        drizzle_free_result(slave);
+        drizzleclient_free_result(slave);
         /* Silently assume that they don't have the slave running */
         return(0);
       }
     }
   }
-  drizzle_free_result(slave);
+  drizzleclient_free_result(slave);
 
   /* now, start slave if stopped */
-  if (drizzle_query_with_error_report(drizzle_con, 0, "START SLAVE"))
+  if (drizzleclient_query_with_error_report(drizzle_con, 0, "START SLAVE"))
   {
     my_printf_error(0, _("Error: Unable to start slave"), MYF(0));
     return 1;
@@ -2805,15 +2805,15 @@
     update starts between the two FLUSHes, we have that bad stall.
   */
   return
-    ( drizzle_query_with_error_report(drizzle_con, 0, "FLUSH TABLES") ||
-      drizzle_query_with_error_report(drizzle_con, 0,
+    ( drizzleclient_query_with_error_report(drizzle_con, 0, "FLUSH TABLES") ||
+      drizzleclient_query_with_error_report(drizzle_con, 0,
                                     "FLUSH TABLES WITH READ LOCK") );
 }
 
 
 static int do_unlock_tables(DRIZZLE *drizzle_con)
 {
-  return drizzle_query_with_error_report(drizzle_con, 0, "UNLOCK TABLES");
+  return drizzleclient_query_with_error_report(drizzle_con, 0, "UNLOCK TABLES");
 }
 
 static int get_bin_log_name(DRIZZLE *drizzle_con,
@@ -2822,13 +2822,13 @@
   DRIZZLE_RES *res;
   DRIZZLE_ROW row;
 
-  if (drizzle_query(drizzle_con, "SHOW MASTER STATUS") ||
-      !(res= drizzle_store_result(drizzle)))
+  if (drizzleclient_query(drizzle_con, "SHOW MASTER STATUS") ||
+      !(res= drizzleclient_store_result(drizzle)))
     return 1;
 
-  if (!(row= drizzle_fetch_row(res)))
+  if (!(row= drizzleclient_fetch_row(res)))
   {
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
     return 1;
   }
   /*
@@ -2837,7 +2837,7 @@
   */
   strncpy(buff_log_name, row[0], buff_len - 1);
 
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
   return 0;
 }
 
@@ -2847,17 +2847,17 @@
   string str= "PURGE BINARY LOGS TO '";
   str.append(log_name);
   str.append("'");
-  err = drizzle_query_with_error_report(drizzle_con, 0, str.c_str());
+  err = drizzleclient_query_with_error_report(drizzle_con, 0, str.c_str());
   return err;
 }
 
 
 static int start_transaction(DRIZZLE *drizzle_con)
 {
-  return (drizzle_query_with_error_report(drizzle_con, 0,
+  return (drizzleclient_query_with_error_report(drizzle_con, 0,
                                         "SET SESSION TRANSACTION ISOLATION "
                                         "LEVEL REPEATABLE READ") ||
-          drizzle_query_with_error_report(drizzle_con, 0,
+          drizzleclient_query_with_error_report(drizzle_con, 0,
                                         "START TRANSACTION "
                                         "WITH CONSISTENT SNAPSHOT"));
 }
@@ -2910,9 +2910,9 @@
                         int string_value)
 {
   DRIZZLE_FIELD   *field;
-  drizzle_field_seek(result, 0);
+  drizzleclient_field_seek(result, 0);
 
-  for ( ; (field= drizzle_fetch_field(result)) ; row++)
+  for ( ; (field= drizzleclient_fetch_field(result)) ; row++)
   {
     if (!strcmp(field->name,name))
     {
@@ -2940,19 +2940,19 @@
 static const char* fetch_named_row(DRIZZLE_RES *result, DRIZZLE_ROW row, const char *name)
 {
   DRIZZLE_FIELD   *field;
-  drizzle_field_seek(result, 0);
-  for ( ; (field= drizzle_fetch_field(result)) ; row++)
+  drizzleclient_field_seek(result, 0);
+  for ( ; (field= drizzleclient_fetch_field(result)) ; row++)
   {
     if (!strcmp(field->name,name))
     {
       if (row[0] && row[0][0] && strcmp(row[0],"0")) /* Skip default */
       {
-        drizzle_field_seek(result, 0);
+        drizzleclient_field_seek(result, 0);
         return row[0];
       }
     }
   }
-  drizzle_field_seek(result, 0);
+  drizzleclient_field_seek(result, 0);
   return NULL;
 }
 
@@ -2993,21 +2993,21 @@
   assert(2*sizeof(table_name) < sizeof(show_name_buff));
   snprintf(buff, sizeof(buff), "show table status like %s",
            quote_for_like(table_name, show_name_buff));
-  if (drizzle_query_with_error_report(drizzle, &res, buff))
+  if (drizzleclient_query_with_error_report(drizzle, &res, buff))
   {
-    if (drizzle_errno(drizzle) != ER_PARSE_ERROR)
+    if (drizzleclient_errno(drizzle) != ER_PARSE_ERROR)
     {                                   /* If old DRIZZLE version */
       verbose_msg(_("-- Warning: Couldn't get status information for "
-                  "table %s (%s)\n"), table_name, drizzle_error(drizzle));
+                  "table %s (%s)\n"), table_name, drizzleclient_error(drizzle));
       return(result);                       /* assume table is ok */
     }
   }
-  if (!(row= drizzle_fetch_row(res)))
+  if (!(row= drizzleclient_fetch_row(res)))
   {
     fprintf(stderr,
             _("Error: Couldn't read status information for table %s (%s)\n"),
-            table_name, drizzle_error(drizzle));
-    drizzle_free_result(res);
+            table_name, drizzleclient_error(drizzle));
+    drizzleclient_free_result(res);
     return(result);                         /* assume table is ok */
   }
   else
@@ -3034,7 +3034,7 @@
         result= IGNORE_INSERT_DELAYED;
     }
   }
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
   return(result);
 }
 
@@ -3070,12 +3070,12 @@
 
   snprintf(show_keys_buff, sizeof(show_keys_buff),
            "SHOW KEYS FROM %s", table_name);
-  if (drizzle_query(drizzle, show_keys_buff) ||
-      !(res= drizzle_store_result(drizzle)))
+  if (drizzleclient_query(drizzle, show_keys_buff) ||
+      !(res= drizzleclient_store_result(drizzle)))
   {
     fprintf(stderr, _("Warning: Couldn't read keys from table %s;"
             " records are NOT sorted (%s)\n"),
-            table_name, drizzle_error(drizzle));
+            table_name, drizzleclient_error(drizzle));
     /* Don't exit, because it's better to print out unsorted records */
     goto cleanup;
   }
@@ -3086,14 +3086,14 @@
    * row, and UNIQUE keys come before others.  So we only need to check
    * the first key, not all keys.
    */
-  if ((row= drizzle_fetch_row(res)) && atoi(row[1]) == 0)
+  if ((row= drizzleclient_fetch_row(res)) && atoi(row[1]) == 0)
   {
     /* Key is unique */
     do
     {
       quoted_field= quote_name(row[4], buff, 0);
       result_length+= strlen(quoted_field) + 1; /* + 1 for ',' or \0 */
-    } while ((row= drizzle_fetch_row(res)) && atoi(row[3]) > 1);
+    } while ((row= drizzleclient_fetch_row(res)) && atoi(row[3]) > 1);
   }
 
   /* Build the ORDER BY clause result */
@@ -3107,11 +3107,11 @@
       fprintf(stderr, _("Error: Not enough memory to store ORDER BY clause\n"));
       goto cleanup;
     }
-    drizzle_data_seek(res, 0);
-    row= drizzle_fetch_row(res);
+    drizzleclient_data_seek(res, 0);
+    row= drizzleclient_fetch_row(res);
     quoted_field= quote_name(row[4], buff, 0);
     end= strcpy(result, quoted_field) + strlen(quoted_field);
-    while ((row= drizzle_fetch_row(res)) && atoi(row[3]) > 1)
+    while ((row= drizzleclient_fetch_row(res)) && atoi(row[3]) > 1)
     {
       quoted_field= quote_name(row[4], buff, 0);
       end+= sprintf(end,",%s",quoted_field);
@@ -3120,7 +3120,7 @@
 
 cleanup:
   if (res)
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
 
   return result;
 }
@@ -3161,14 +3161,14 @@
       goto err;
   if (opt_delete_master_logs)
   {
-    if (drizzle_refresh(drizzle, REFRESH_LOG) ||
+    if (drizzleclient_refresh(drizzle, REFRESH_LOG) ||
         get_bin_log_name(drizzle, bin_log_name, sizeof(bin_log_name)))
       goto err;
     flush_logs= 0;
   }
   if (opt_lock_all_tables || opt_master_data)
   {
-    if (flush_logs && drizzle_refresh(drizzle, REFRESH_LOG))
+    if (flush_logs && drizzleclient_refresh(drizzle, REFRESH_LOG))
       goto err;
     flush_logs= 0; /* not anymore; that would not be sensible */
   }

=== modified file 'client/drizzleimport.cc'
--- client/drizzleimport.cc	2009-02-08 11:11:30 +0000
+++ client/drizzleimport.cc	2009-02-08 11:28:58 +0000
@@ -162,7 +162,7 @@
 static void print_version(void)
 {
   printf("%s  Ver %s Distrib %s, for %s (%s)\n" ,my_progname,
-    IMPORT_VERSION, drizzle_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+    IMPORT_VERSION, drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 
@@ -311,7 +311,7 @@
 #else
     sprintf(sql_statement, "DELETE FROM %s", tablename);
 #endif
-    if (drizzle_query(drizzle, sql_statement))
+    if (drizzleclient_query(drizzle, sql_statement))
     {
       db_error_with_table(drizzle, tablename);
       return(1);
@@ -359,17 +359,17 @@
   }
   *end= '\0';
 
-  if (drizzle_query(drizzle, sql_statement))
+  if (drizzleclient_query(drizzle, sql_statement))
   {
     db_error_with_table(drizzle, tablename);
     return(1);
   }
   if (!silent)
   {
-    if (drizzle_info(drizzle)) /* If NULL-pointer, print nothing */
+    if (drizzleclient_info(drizzle)) /* If NULL-pointer, print nothing */
     {
       fprintf(stdout, "%s.%s: %s\n", current_db, tablename,
-        drizzle_info(drizzle));
+        drizzleclient_info(drizzle));
     }
   }
   return(0);
@@ -392,7 +392,7 @@
     query.append(tablename);
     query.append(" WRITE,");
   }
-  if (drizzle_real_query(drizzle, query.c_str(), query.length()-1))
+  if (drizzleclient_real_query(drizzle, query.c_str(), query.length()-1))
     db_error(drizzle); /* We shall countinue here, if --force was given */
 }
 
@@ -405,16 +405,16 @@
   DRIZZLE *drizzle;
   if (verbose)
     fprintf(stdout, "Connecting to %s\n", host ? host : "localhost");
-  if (!(drizzle= drizzle_create(NULL)))
+  if (!(drizzle= drizzleclient_create(NULL)))
     return 0;
   if (opt_compress)
-    drizzle_options(drizzle,DRIZZLE_OPT_COMPRESS,NULL);
+    drizzleclient_options(drizzle,DRIZZLE_OPT_COMPRESS,NULL);
   if (opt_local_file)
-    drizzle_options(drizzle,DRIZZLE_OPT_LOCAL_INFILE,
+    drizzleclient_options(drizzle,DRIZZLE_OPT_LOCAL_INFILE,
       (char*) &opt_local_file);
   if (opt_protocol)
-    drizzle_options(drizzle,DRIZZLE_OPT_PROTOCOL,(char*)&opt_protocol);
-  if (!(drizzle_connect(drizzle,host,user,passwd,
+    drizzleclient_options(drizzle,DRIZZLE_OPT_PROTOCOL,(char*)&opt_protocol);
+  if (!(drizzleclient_connect(drizzle,host,user,passwd,
                            database,opt_drizzle_port,opt_drizzle_unix_port,
                            0)))
   {
@@ -424,7 +424,7 @@
   drizzle->reconnect= 0;
   if (verbose)
     fprintf(stdout, "Selecting database %s\n", database);
-  if (drizzle_select_db(drizzle, database))
+  if (drizzleclient_select_db(drizzle, database))
   {
     ignore_errors=0;
     db_error(drizzle);
@@ -438,7 +438,7 @@
 {
   if (verbose)
     fprintf(stdout, "Disconnecting from %s\n", host ? host : "localhost");
-  drizzle_close(drizzle);
+  drizzleclient_close(drizzle);
 }
 
 
@@ -448,7 +448,7 @@
   if (ignore_errors)
     return;
   if (drizzle)
-    drizzle_close(drizzle);
+    drizzleclient_close(drizzle);
   exit(error);
 }
 
@@ -457,7 +457,7 @@
 static void db_error_with_table(DRIZZLE *drizzle, char *table)
 {
   my_printf_error(0,"Error: %d, %s, when using table: %s",
-      MYF(0), drizzle_errno(drizzle), drizzle_error(drizzle), table);
+      MYF(0), drizzleclient_errno(drizzle), drizzleclient_error(drizzle), table);
   safe_exit(1, drizzle);
 }
 
@@ -465,7 +465,7 @@
 
 static void db_error(DRIZZLE *drizzle)
 {
-  my_printf_error(0,"Error: %d %s", MYF(0), drizzle_errno(drizzle), drizzle_error(drizzle));
+  my_printf_error(0,"Error: %d %s", MYF(0), drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
   safe_exit(1, drizzle);
 }
 
@@ -533,7 +533,7 @@
     goto error;
   }
 
-  if (drizzle_query(drizzle, "/*!40101 set @@character_set_database=binary */;"))
+  if (drizzleclient_query(drizzle, "/*!40101 set @@character_set_database=binary */;"))
   {
     db_error(drizzle); /* We shall countinue here, if --force was given */
     goto error;
@@ -638,7 +638,7 @@
       return(1); /* purecov: deadcode */
     }
 
-    if (drizzle_query(drizzle, "/*!40101 set @@character_set_database=binary */;"))
+    if (drizzleclient_query(drizzle, "/*!40101 set @@character_set_database=binary */;"))
     {
       db_error(drizzle); /* We shall countinue here, if --force was given */
       return(1);

=== modified file 'client/drizzleslap.cc'
--- client/drizzleslap.cc	2009-02-08 11:11:30 +0000
+++ client/drizzleslap.cc	2009-02-08 11:28:58 +0000
@@ -717,7 +717,7 @@
 static void print_version(void)
 {
   printf("%s  Ver %s Distrib %s, for %s (%s)\n",my_progname, SLAP_VERSION,
-         drizzle_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+         drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 
@@ -1763,7 +1763,7 @@
 
   if (verbose >= 3)
     printf("%.*s;\n", len, query);
-  return drizzle_real_query(drizzle, query, len);
+  return drizzleclient_real_query(drizzle, query, len);
 }
 
 
@@ -1805,12 +1805,12 @@
     if (run_query(drizzle, "SELECT id from t1", strlen("SELECT id from t1")))
     {
       fprintf(stderr,"%s: Cannot select GUID primary keys. (%s)\n", my_progname,
-              drizzle_error(drizzle));
+              drizzleclient_error(drizzle));
       exit(1);
     }
 
-    result= drizzle_store_result(drizzle);
-    uint64_t num_rows_ret= drizzle_num_rows(result);
+    result= drizzleclient_store_result(drizzle);
+    uint64_t num_rows_ret= drizzleclient_num_rows(result);
     if (num_rows_ret > SIZE_MAX)
     {
       fprintf(stderr, "More primary keys than than architecture supports\n");
@@ -1832,9 +1832,9 @@
         exit(1);
       }
       memset(primary_keys, 0, (size_t)(sizeof(char *) * primary_keys_number_of));
-      row= drizzle_fetch_row(result);
+      row= drizzleclient_fetch_row(result);
       for (counter= 0; counter < primary_keys_number_of;
-           counter++, row= drizzle_fetch_row(result))
+           counter++, row= drizzleclient_fetch_row(result))
       {
         primary_keys[counter]= strdup(row[0]);
         if (primary_keys[counter] == NULL)
@@ -1845,7 +1845,7 @@
       }
     }
 
-    drizzle_free_result(result);
+    drizzleclient_free_result(result);
   }
 
   return(0);
@@ -1889,7 +1889,7 @@
   if (run_query(drizzle, query, len))
   {
     fprintf(stderr,"%s: Cannot create schema %s : %s\n", my_progname, db,
-            drizzle_error(drizzle));
+            drizzleclient_error(drizzle));
     exit(1);
   }
   else
@@ -1906,10 +1906,10 @@
     if (verbose >= 3)
       printf("%s;\n", query);
 
-    if (drizzle_select_db(drizzle,  db))
+    if (drizzleclient_select_db(drizzle,  db))
     {
       fprintf(stderr,"%s: Cannot select schema '%s': %s\n",my_progname, db,
-              drizzle_error(drizzle));
+              drizzleclient_error(drizzle));
       exit(1);
     }
     sptr->create_count++;
@@ -1922,7 +1922,7 @@
     if (run_query(drizzle, query, len))
     {
       fprintf(stderr,"%s: Cannot set default engine: %s\n", my_progname,
-              drizzle_error(drizzle));
+              drizzleclient_error(drizzle));
       exit(1);
     }
     sptr->create_count++;
@@ -1946,7 +1946,7 @@
       if (run_query(drizzle, buffer, strlen(buffer)))
       {
         fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-                my_progname, (uint)ptr->length, ptr->string, drizzle_error(drizzle));
+                my_progname, (uint)ptr->length, ptr->string, drizzleclient_error(drizzle));
         if (!opt_ignore_sql_errors)
           exit(1);
       }
@@ -1957,7 +1957,7 @@
       if (run_query(drizzle, ptr->string, ptr->length))
       {
         fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-                my_progname, (uint)ptr->length, ptr->string, drizzle_error(drizzle));
+                my_progname, (uint)ptr->length, ptr->string, drizzleclient_error(drizzle));
         if (!opt_ignore_sql_errors)
           exit(1);
       }
@@ -1990,7 +1990,7 @@
   if (run_query(drizzle, query, len))
   {
     fprintf(stderr,"%s: Cannot drop database '%s' ERROR : %s\n",
-            my_progname, db, drizzle_error(drizzle));
+            my_progname, db, drizzleclient_error(drizzle));
     exit(1);
   }
 
@@ -2011,15 +2011,15 @@
     if (run_query(drizzle, ptr->string, ptr->length))
     {
       fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-              my_progname, (uint)ptr->length, ptr->string, drizzle_error(drizzle));
+              my_progname, (uint)ptr->length, ptr->string, drizzleclient_error(drizzle));
       exit(1);
     }
     if (!opt_only_print)
     {
-      if (drizzle_field_count(drizzle))
+      if (drizzleclient_field_count(drizzle))
       {
-        result= drizzle_store_result(drizzle);
-        drizzle_free_result(result);
+        result= drizzleclient_store_result(drizzle);
+        drizzleclient_free_result(result);
       }
     }
   }
@@ -2244,7 +2244,7 @@
         if (run_query(&drizzle, buffer, length))
         {
           fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-                  my_progname, (uint)length, buffer, drizzle_error(&drizzle));
+                  my_progname, (uint)length, buffer, drizzleclient_error(&drizzle));
           exit(1);
         }
       }
@@ -2254,7 +2254,7 @@
       if (run_query(&drizzle, ptr->string, ptr->length))
       {
         fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-                my_progname, (uint)ptr->length, ptr->string, drizzle_error(&drizzle));
+                my_progname, (uint)ptr->length, ptr->string, drizzleclient_error(&drizzle));
         exit(1);
       }
     }
@@ -2263,14 +2263,14 @@
     {
       do
       {
-        if (drizzle_field_count(&drizzle))
+        if (drizzleclient_field_count(&drizzle))
         {
-          result= drizzle_store_result(&drizzle);
-          while ((row = drizzle_fetch_row(result)))
+          result= drizzleclient_store_result(&drizzle);
+          while ((row = drizzleclient_fetch_row(result)))
             counter++;
-          drizzle_free_result(result);
+          drizzleclient_free_result(result);
         }
-      } while(drizzle_next_result(&drizzle) == 0);
+      } while(drizzleclient_next_result(&drizzle) == 0);
     }
     queries++;
 
@@ -2674,7 +2674,7 @@
   if (opt_only_print)
     return;
 
-  drizzle_close(drizzle);
+  drizzleclient_close(drizzle);
 }
 
 void
@@ -2690,16 +2690,16 @@
   if (opt_delayed_start)
     usleep(random()%opt_delayed_start);
 
-  drizzle_create(drizzle);
+  drizzleclient_create(drizzle);
 
   if (opt_compress)
-    drizzle_options(drizzle,DRIZZLE_OPT_COMPRESS,NULL);
+    drizzleclient_options(drizzle,DRIZZLE_OPT_COMPRESS,NULL);
 
   for (x= 0; x < 10; x++)
   {
 
 
-    if (drizzle_connect(drizzle, host, user, opt_password,
+    if (drizzleclient_connect(drizzle, host, user, opt_password,
                         connect_to_schema ? create_schema_string : NULL,
                         opt_drizzle_port,
                         opt_drizzle_unix_port,
@@ -2714,7 +2714,7 @@
   if (connect_error)
   {
     fprintf(stderr,"%s: Error when connecting to server: %d %s\n",
-            my_progname, drizzle_errno(drizzle), drizzle_error(drizzle));
+            my_progname, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
     exit(1);
   }
 

=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2009-02-08 11:11:30 +0000
+++ client/drizzletest.cc	2009-02-08 11:28:58 +0000
@@ -444,7 +444,7 @@
 void handle_no_error(struct st_command*);
 
 
-#define do_send_query(cn,q,q_len,flags) drizzle_send_query(&cn->drizzle, q, q_len)
+#define do_send_query(cn,q,q_len,flags) drizzleclient_send_query(&cn->drizzle, q, q_len)
 
 void do_eval(string *query_eval, const char *query,
              const char *query_end, bool pass_through_escape_chars)
@@ -567,14 +567,14 @@
   if (!drizzle)
     return;
 
-  if (drizzle_query(drizzle, query))
+  if (drizzleclient_query(drizzle, query))
   {
     log_msg("Error running query '%s': %d %s",
-            query, drizzle_errno(drizzle), drizzle_error(drizzle));
+            query, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
     return;
   }
 
-  if ((res= drizzle_store_result(drizzle)) == NULL)
+  if ((res= drizzleclient_store_result(drizzle)) == NULL)
   {
     /* No result set returned */
     return;
@@ -584,13 +584,13 @@
     DRIZZLE_ROW row;
     unsigned int i;
     unsigned int row_num= 0;
-    unsigned int num_fields= drizzle_num_fields(res);
-    const DRIZZLE_FIELD *fields= drizzle_fetch_fields(res);
+    unsigned int num_fields= drizzleclient_num_fields(res);
+    const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
 
     fprintf(stderr, "=== %s ===\n", query);
-    while ((row= drizzle_fetch_row(res)))
+    while ((row= drizzleclient_fetch_row(res)))
     {
-      uint32_t *lengths= drizzle_fetch_lengths(res);
+      uint32_t *lengths= drizzleclient_fetch_lengths(res);
       row_num++;
 
       fprintf(stderr, "---- %d. ----\n", row_num);
@@ -605,7 +605,7 @@
       fprintf(stderr, "=");
     fprintf(stderr, "\n\n");
   }
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
 
   return;
 }
@@ -633,20 +633,20 @@
   if (!drizzle)
     return;
 
-  if (drizzle_query(drizzle, query))
+  if (drizzleclient_query(drizzle, query))
   {
     log_msg("Error running query '%s': %d %s",
-            query, drizzle_errno(drizzle), drizzle_error(drizzle));
+            query, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
     return;
   }
 
-  if ((res= drizzle_store_result(drizzle)) == NULL)
+  if ((res= drizzleclient_store_result(drizzle)) == NULL)
   {
     /* No result set returned */
     return;
   }
 
-  if (drizzle_num_rows(res) <= 1)
+  if (drizzleclient_num_rows(res) <= 1)
   {
     /* Don't display the last row, it's "last error" */
   }
@@ -654,15 +654,15 @@
   {
     DRIZZLE_ROW row;
     unsigned int row_num= 0;
-    unsigned int num_fields= drizzle_num_fields(res);
+    unsigned int num_fields= drizzleclient_num_fields(res);
 
     fprintf(stderr, "\nWarnings from just before the error:\n");
-    while ((row= drizzle_fetch_row(res)))
+    while ((row= drizzleclient_fetch_row(res)))
     {
       uint32_t i;
-      uint32_t *lengths= drizzle_fetch_lengths(res);
+      uint32_t *lengths= drizzleclient_fetch_lengths(res);
 
-      if (++row_num >= drizzle_num_rows(res))
+      if (++row_num >= drizzleclient_num_rows(res))
       {
         /* Don't display the last row, it's "last error" */
         break;
@@ -676,7 +676,7 @@
       fprintf(stderr, "\n");
     }
   }
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
 
   return;
 }
@@ -805,9 +805,9 @@
 
   for (--next_con; next_con >= connections; --next_con)
   {
-    drizzle_close(&next_con->drizzle);
+    drizzleclient_close(&next_con->drizzle);
     if (next_con->util_drizzle)
-      drizzle_close(next_con->util_drizzle);
+      drizzleclient_close(next_con->util_drizzle);
     free(next_con->name);
   }
   return;
@@ -1756,23 +1756,23 @@
 
 /*
   Store an integer (typically the returncode of the last SQL)
-  statement in the drizzletest builtin variable $drizzle_errno
+  statement in the drizzletest builtin variable $drizzleclient_errno
 */
 
 static void var_set_errno(int sql_errno)
 {
-  var_set_int("$drizzle_errno", sql_errno);
+  var_set_int("$drizzleclient_errno", sql_errno);
 }
 
 
 /*
-  Update $drizzle_get_server_version variable with version
+  Update $drizzleclient_get_server_version variable with version
   of the currently connected server
 */
 
-static void var_set_drizzle_get_server_version(DRIZZLE *drizzle)
+static void var_set_drizzleclient_get_server_version(DRIZZLE *drizzle)
 {
-  var_set_int("$drizzle_get_server_version", drizzle_get_server_version(drizzle));
+  var_set_int("$drizzleclient_get_server_version", drizzleclient_get_server_version(drizzle));
 }
 
 
@@ -1818,13 +1818,13 @@
   /* Eval the query, thus replacing all environment variables */
   do_eval(&ds_query, query, end, false);
 
-  if (drizzle_real_query(drizzle, ds_query.c_str(), ds_query.length()))
+  if (drizzleclient_real_query(drizzle, ds_query.c_str(), ds_query.length()))
     die("Error running query '%s': %d %s", ds_query.c_str(),
-        drizzle_errno(drizzle), drizzle_error(drizzle));
-  if (!(res= drizzle_store_result(drizzle)))
+        drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+  if (!(res= drizzleclient_store_result(drizzle)))
     die("Query '%s' didn't return a result set", ds_query.c_str());
 
-  if ((row= drizzle_fetch_row(res)) && row[0])
+  if ((row= drizzleclient_fetch_row(res)) && row[0])
   {
     /*
       Concatenate all fields in the first row with tab in between
@@ -1834,8 +1834,8 @@
     uint32_t i;
     uint32_t *lengths;
 
-    lengths= drizzle_fetch_lengths(res);
-    for (i= 0; i < drizzle_num_fields(res); i++)
+    lengths= drizzleclient_fetch_lengths(res);
+    for (i= 0; i < drizzleclient_num_fields(res); i++)
     {
       if (row[i])
       {
@@ -1850,7 +1850,7 @@
   else
     eval_expr(var, "", 0);
 
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
   return;
 }
 
@@ -1913,17 +1913,17 @@
   ds_query.append(unstripped_query);
 
   /* Run the query */
-  if (drizzle_real_query(drizzle, ds_query.c_str(), ds_query.length()))
+  if (drizzleclient_real_query(drizzle, ds_query.c_str(), ds_query.length()))
     die("Error running query '%s': %d %s", ds_query.c_str(),
-        drizzle_errno(drizzle), drizzle_error(drizzle));
-  if (!(res= drizzle_store_result(drizzle)))
+        drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+  if (!(res= drizzleclient_store_result(drizzle)))
     die("Query '%s' didn't return a result set", ds_query.c_str());
 
   {
     /* Find column number from the given column name */
     uint i;
-    uint num_fields= drizzle_num_fields(res);
-    const DRIZZLE_FIELD *fields= drizzle_fetch_fields(res);
+    uint num_fields= drizzleclient_num_fields(res);
+    const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
 
     for (i= 0; i < num_fields; i++)
     {
@@ -1936,7 +1936,7 @@
     }
     if (col_no == -1)
     {
-      drizzle_free_result(res);
+      drizzleclient_free_result(res);
       die("Could not find column '%s' in the result of '%s'",
           ds_col.c_str(), ds_query.c_str());
     }
@@ -1948,7 +1948,7 @@
     long rows= 0;
     const char* value= "No such row";
 
-    while ((row= drizzle_fetch_row(res)))
+    while ((row= drizzleclient_fetch_row(res)))
     {
       if (++rows == row_no)
       {
@@ -1964,7 +1964,7 @@
     }
     eval_expr(var, value, 0);
   }
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
 
   return;
 }
@@ -2872,9 +2872,9 @@
   if (!ds_db.length())
     ds_db.append(drizzle->db);
 
-  if (drizzle_change_user(drizzle, ds_user.c_str(),
+  if (drizzleclient_change_user(drizzle, ds_user.c_str(),
                           ds_passwd.c_str(), ds_db.c_str()))
-    die("change user failed: %s", drizzle_error(drizzle));
+    die("change user failed: %s", drizzleclient_error(drizzle));
 
 
   return;
@@ -3006,17 +3006,17 @@
     DRIZZLE_ROW row;
     int done;
 
-    if (drizzle_query(drizzle,"show status like 'Slave_running'") ||
-        !(res=drizzle_store_result(drizzle)))
+    if (drizzleclient_query(drizzle,"show status like 'Slave_running'") ||
+        !(res=drizzleclient_store_result(drizzle)))
       die("Query failed while probing slave for stop: %s",
-          drizzle_error(drizzle));
-    if (!(row=drizzle_fetch_row(res)) || !row[1])
+          drizzleclient_error(drizzle));
+    if (!(row=drizzleclient_fetch_row(res)) || !row[1])
     {
-      drizzle_free_result(res);
+      drizzleclient_free_result(res);
       die("Strange result from query while probing slave for stop");
     }
     done = !strcmp(row[1],"OFF");
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
     if (done)
       break;
     usleep(SLAVE_POLL_INTERVAL);
@@ -3041,15 +3041,15 @@
 
 wait_for_position:
 
-  if (drizzle_query(drizzle, query_buf))
-    die("failed in '%s': %d: %s", query_buf, drizzle_errno(drizzle),
-        drizzle_error(drizzle));
+  if (drizzleclient_query(drizzle, query_buf))
+    die("failed in '%s': %d: %s", query_buf, drizzleclient_errno(drizzle),
+        drizzleclient_error(drizzle));
 
-  if (!(res= drizzle_store_result(drizzle)))
-    die("drizzle_store_result() returned NULL for '%s'", query_buf);
-  if (!(row= drizzle_fetch_row(res)))
+  if (!(res= drizzleclient_store_result(drizzle)))
+    die("drizzleclient_store_result() returned NULL for '%s'", query_buf);
+  if (!(row= drizzleclient_fetch_row(res)))
   {
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
     die("empty result in %s", query_buf);
   }
   if (!row[0])
@@ -3058,7 +3058,7 @@
       It may be that the slave SQL thread has not started yet, though START
       SLAVE has been issued ?
     */
-    drizzle_free_result(res);
+    drizzleclient_free_result(res);
     if (tries++ == 30)
     {
       show_query(drizzle, "SHOW MASTER STATUS");
@@ -3068,7 +3068,7 @@
     sleep(1); /* So at most we will wait 30 seconds and make 31 tries */
     goto wait_for_position;
   }
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
   return;
 }
 
@@ -3104,17 +3104,17 @@
   const char *query;
 
 
-  if (drizzle_query(drizzle, query= "show master status"))
+  if (drizzleclient_query(drizzle, query= "show master status"))
     die("failed in 'show master status': %d %s",
-        drizzle_errno(drizzle), drizzle_error(drizzle));
+        drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
 
-  if (!(res = drizzle_store_result(drizzle)))
-    die("drizzle_store_result() retuned NULL for '%s'", query);
-  if (!(row = drizzle_fetch_row(res)))
+  if (!(res = drizzleclient_store_result(drizzle)))
+    die("drizzleclient_store_result() retuned NULL for '%s'", query);
+  if (!(row = drizzleclient_fetch_row(res)))
     die("empty result in show master status");
   strncpy(master_pos.file, row[0], sizeof(master_pos.file)-1);
   master_pos.pos = strtoul(row[1], (char**) 0, 10);
-  drizzle_free_result(res);
+  drizzleclient_free_result(res);
   return(0);
 }
 
@@ -3481,7 +3481,7 @@
 {
   bool reconnect= val;
 
-  drizzle_options(drizzle, DRIZZLE_OPT_RECONNECT, (char *)&reconnect);
+  drizzleclient_options(drizzle, DRIZZLE_OPT_RECONNECT, (char *)&reconnect);
 
   return;
 }
@@ -3492,8 +3492,8 @@
   if (!(cur_con= find_connection_by_name(name)))
     die("connection '%s' not found in connection pool", name);
 
-  /* Update $drizzle_get_server_version to that of current connection */
-  var_set_drizzle_get_server_version(&cur_con->drizzle);
+  /* Update $drizzleclient_get_server_version to that of current connection */
+  var_set_drizzleclient_get_server_version(&cur_con->drizzle);
 
   return(0);
 }
@@ -3543,10 +3543,10 @@
     }
   }
 
-  drizzle_close(&con->drizzle);
+  drizzleclient_close(&con->drizzle);
 
   if (con->util_drizzle)
-    drizzle_close(con->util_drizzle);
+    drizzleclient_close(con->util_drizzle);
   con->util_drizzle= 0;
 
   free(con->name);
@@ -3595,7 +3595,7 @@
   static uint32_t connection_retry_sleep= 100000; /* Microseconds */
 
 
-  while(!drizzle_connect(drizzle, host, user, pass, db, port, NULL,
+  while(!drizzleclient_connect(drizzle, host, user, pass, db, port, NULL,
                          CLIENT_MULTI_STATEMENTS | CLIENT_REMEMBER_OPTIONS))
   {
     /*
@@ -3606,23 +3606,23 @@
       on protocol/connection type
     */
 
-    if ((drizzle_errno(drizzle) == CR_CONN_HOST_ERROR ||
-         drizzle_errno(drizzle) == CR_CONNECTION_ERROR) &&
+    if ((drizzleclient_errno(drizzle) == CR_CONN_HOST_ERROR ||
+         drizzleclient_errno(drizzle) == CR_CONNECTION_ERROR) &&
         failed_attempts < opt_max_connect_retries)
     {
       verbose_msg("Connect attempt %d/%d failed: %d: %s", failed_attempts,
-                  opt_max_connect_retries, drizzle_errno(drizzle),
-                  drizzle_error(drizzle));
+                  opt_max_connect_retries, drizzleclient_errno(drizzle),
+                  drizzleclient_error(drizzle));
       usleep(connection_retry_sleep);
     }
     else
     {
       if (failed_attempts > 0)
         die("Could not open connection '%s' after %d attempts: %d %s", name,
-            failed_attempts, drizzle_errno(drizzle), drizzle_error(drizzle));
+            failed_attempts, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
       else
         die("Could not open connection '%s': %d %s", name,
-            drizzle_errno(drizzle), drizzle_error(drizzle));
+            drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
     }
     failed_attempts++;
   }
@@ -3684,12 +3684,12 @@
     ds_res.append(delimiter);
     ds_res.append("\n");
   }
-  if (!drizzle_connect(con, host, user, pass, db, port, 0,
+  if (!drizzleclient_connect(con, host, user, pass, db, port, 0,
                        CLIENT_MULTI_STATEMENTS))
   {
-    var_set_errno(drizzle_errno(con));
-    handle_error(command, drizzle_errno(con), drizzle_error(con),
-                 drizzle_sqlstate(con), &ds_res);
+    var_set_errno(drizzleclient_errno(con));
+    handle_error(command, drizzleclient_errno(con), drizzleclient_error(con),
+                 drizzleclient_sqlstate(con), &ds_res);
     return 0; /* Not connected */
   }
 
@@ -3817,11 +3817,11 @@
           (int) (sizeof(connections)/sizeof(struct st_connection)));
   }
 
-  if (!drizzle_create(&con_slot->drizzle))
-    die("Failed on drizzle_create()");
+  if (!drizzleclient_create(&con_slot->drizzle))
+    die("Failed on drizzleclient_create()");
   if (opt_compress || con_compress)
-    drizzle_options(&con_slot->drizzle, DRIZZLE_OPT_COMPRESS, NULL);
-  drizzle_options(&con_slot->drizzle, DRIZZLE_OPT_LOCAL_INFILE, 0);
+    drizzleclient_options(&con_slot->drizzle, DRIZZLE_OPT_COMPRESS, NULL);
+  drizzleclient_options(&con_slot->drizzle, DRIZZLE_OPT_LOCAL_INFILE, 0);
 
   /* Use default db name */
   if (ds_database.length() == 0)
@@ -3844,8 +3844,8 @@
       next_con++; /* if we used the next_con slot, advance the pointer */
   }
 
-  /* Update $drizzle_get_server_version to that of current connection */
-  var_set_drizzle_get_server_version(&cur_con->drizzle);
+  /* Update $drizzleclient_get_server_version to that of current connection */
+  var_set_drizzleclient_get_server_version(&cur_con->drizzle);
 
   return;
 }
@@ -4530,7 +4530,7 @@
 static void print_version(void)
 {
   printf("%s  Ver %s Distrib %s, for %s (%s)\n",my_progname,MTEST_VERSION,
-         drizzle_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+         drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 static void usage(void)
@@ -4851,14 +4851,14 @@
 static void append_result(string *ds, DRIZZLE_RES *res)
 {
   DRIZZLE_ROW row;
-  uint32_t num_fields= drizzle_num_fields(res);
-  const DRIZZLE_FIELD *fields= drizzle_fetch_fields(res);
+  uint32_t num_fields= drizzleclient_num_fields(res);
+  const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
   uint32_t *lengths;
 
-  while ((row = drizzle_fetch_row(res)))
+  while ((row = drizzleclient_fetch_row(res)))
   {
     uint32_t i;
-    lengths = drizzle_fetch_lengths(res);
+    lengths = drizzleclient_fetch_lengths(res);
     for (i = 0; i < num_fields; i++)
       append_field(ds, i, &fields[i],
                    (const char*)row[i], lengths[i], !row[i]);
@@ -4971,7 +4971,7 @@
   DRIZZLE_RES *warn_res;
 
 
-  if (!(count= drizzle_warning_count(drizzle)))
+  if (!(count= drizzleclient_warning_count(drizzle)))
     return(0);
 
   /*
@@ -4979,12 +4979,12 @@
     through PS API we should not issue SHOW WARNINGS until
     we have not read all results...
   */
-  assert(!drizzle_more_results(drizzle));
-
-  if (drizzle_real_query(drizzle, "SHOW WARNINGS", 13))
-    die("Error running query \"SHOW WARNINGS\": %s", drizzle_error(drizzle));
-
-  if (!(warn_res= drizzle_store_result(drizzle)))
+  assert(!drizzleclient_more_results(drizzle));
+
+  if (drizzleclient_real_query(drizzle, "SHOW WARNINGS", 13))
+    die("Error running query \"SHOW WARNINGS\": %s", drizzleclient_error(drizzle));
+
+  if (!(warn_res= drizzleclient_store_result(drizzle)))
     die("Warning count is %u but didn't get any warnings",
         count);
 
@@ -5023,8 +5023,8 @@
      */
     if (do_send_query(cn, query, query_len, flags))
     {
-      handle_error(command, drizzle_errno(drizzle), drizzle_error(drizzle),
-                   drizzle_sqlstate(drizzle), ds);
+      handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
+                   drizzleclient_sqlstate(drizzle), ds);
       goto end;
     }
   }
@@ -5034,13 +5034,13 @@
   do
   {
     /*
-      When  on first result set, call drizzle_read_query_result to retrieve
+      When  on first result set, call drizzleclient_read_query_result to retrieve
       answer to the query sent earlier
     */
-    if ((counter==0) && drizzle_read_query_result(drizzle))
+    if ((counter==0) && drizzleclient_read_query_result(drizzle))
     {
-      handle_error(command, drizzle_errno(drizzle), drizzle_error(drizzle),
-                   drizzle_sqlstate(drizzle), ds);
+      handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
+                   drizzleclient_sqlstate(drizzle), ds);
       goto end;
 
     }
@@ -5048,10 +5048,10 @@
     /*
       Store the result of the query if it will return any fields
     */
-    if (drizzle_field_count(drizzle) && ((res= drizzle_store_result(drizzle)) == 0))
+    if (drizzleclient_field_count(drizzle) && ((res= drizzleclient_store_result(drizzle)) == 0))
     {
-      handle_error(command, drizzle_errno(drizzle), drizzle_error(drizzle),
-                   drizzle_sqlstate(drizzle), ds);
+      handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
+                   drizzleclient_sqlstate(drizzle), ds);
       goto end;
     }
 
@@ -5061,8 +5061,8 @@
 
       if (res)
       {
-        const DRIZZLE_FIELD *fields= drizzle_fetch_fields(res);
-        uint num_fields= drizzle_num_fields(res);
+        const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
+        uint num_fields= drizzleclient_num_fields(res);
 
         if (display_metadata)
           append_metadata(ds, fields, num_fields);
@@ -5074,18 +5074,18 @@
       }
 
       /*
-        Need to call drizzle_affected_rows() before the "new"
+        Need to call drizzleclient_affected_rows() before the "new"
         query to find the warnings
       */
       if (!disable_info)
-        affected_rows= drizzle_affected_rows(drizzle);
+        affected_rows= drizzleclient_affected_rows(drizzle);
 
       /*
         Add all warnings to the result. We can't do this if we are in
         the middle of processing results from multi-statement, because
         this will break protocol.
       */
-      if (!disable_warnings && !drizzle_more_results(drizzle))
+      if (!disable_warnings && !drizzleclient_more_results(drizzle))
       {
         if (append_warnings(ds_warnings, drizzle) || ds_warnings->length())
         {
@@ -5095,21 +5095,21 @@
       }
 
       if (!disable_info)
-        append_info(ds, affected_rows, drizzle_info(drizzle));
+        append_info(ds, affected_rows, drizzleclient_info(drizzle));
     }
 
     if (res)
     {
-      drizzle_free_result(res);
+      drizzleclient_free_result(res);
       res= 0;
     }
     counter++;
-  } while (!(err= drizzle_next_result(drizzle)));
+  } while (!(err= drizzleclient_next_result(drizzle)));
   if (err > 0)
   {
-    /* We got an error from drizzle_next_result, maybe expected */
-    handle_error(command, drizzle_errno(drizzle), drizzle_error(drizzle),
-                 drizzle_sqlstate(drizzle), ds);
+    /* We got an error from drizzleclient_next_result, maybe expected */
+    handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
+                 drizzleclient_sqlstate(drizzle), ds);
     goto end;
   }
   assert(err == -1); /* Successful and there are no more results */
@@ -5120,11 +5120,11 @@
 end:
 
   /*
-    We save the return code (drizzle_errno(drizzle)) from the last call sent
-    to the server into the drizzletest builtin variable $drizzle_errno. This
+    We save the return code (drizzleclient_errno(drizzle)) from the last call sent
+    to the server into the drizzletest builtin variable $drizzleclient_errno. This
     variable then can be used from the test case itself.
   */
-  var_set_errno(drizzle_errno(drizzle));
+  var_set_errno(drizzleclient_errno(drizzle));
   return;
 }
 
@@ -5527,7 +5527,7 @@
                 1024, 0, 0, get_var_key, var_free, MYF(0)))
     die("Variable hash initialization failed");
 
-  var_set_string("$DRIZZLE_SERVER_VERSION", drizzle_get_client_info());
+  var_set_string("$DRIZZLE_SERVER_VERSION", drizzleclient_get_client_info());
 
   memset(&master_pos, 0, sizeof(master_pos));
 
@@ -5552,11 +5552,11 @@
     cur_file->lineno= 1;
   }
   cur_con= connections;
-  if (!( drizzle_create(&cur_con->drizzle)))
-    die("Failed in drizzle_create()");
+  if (!( drizzleclient_create(&cur_con->drizzle)))
+    die("Failed in drizzleclient_create()");
   if (opt_compress)
-    drizzle_options(&cur_con->drizzle,DRIZZLE_OPT_COMPRESS,NULL);
-  drizzle_options(&cur_con->drizzle, DRIZZLE_OPT_LOCAL_INFILE, 0);
+    drizzleclient_options(&cur_con->drizzle,DRIZZLE_OPT_COMPRESS,NULL);
+  drizzleclient_options(&cur_con->drizzle, DRIZZLE_OPT_LOCAL_INFILE, 0);
 
   if (!(cur_con->name = strdup("default")))
     die("Out of memory");
@@ -5568,14 +5568,14 @@
   timer_start= timer_now();
 
   /*
-    Initialize $drizzle_errno with -1, so we can
+    Initialize $drizzleclient_errno with -1, so we can
     - distinguish it from valid values ( >= 0 ) and
     - detect if there was never a command sent to the server
   */
   var_set_errno(-1);
 
-  /* Update $drizzle_get_server_version to that of current connection */
-  var_set_drizzle_get_server_version(&cur_con->drizzle);
+  /* Update $drizzleclient_get_server_version to that of current connection */
+  var_set_drizzleclient_get_server_version(&cur_con->drizzle);
 
   if (opt_include)
   {
@@ -5763,7 +5763,7 @@
         command->last_argument= command->end;
         break;
       case Q_PING:
-        (void) drizzle_ping(&cur_con->drizzle);
+        (void) drizzleclient_ping(&cur_con->drizzle);
         break;
       case Q_EXEC:
         do_exec(command);

=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2009-02-05 09:40:42 +0000
+++ drizzled/db.cc	2009-02-08 11:28:58 +0000
@@ -310,12 +310,12 @@
 
   /*
     Do not create database if another thread is holding read lock.
-    Wait for global read lock before acquiring LOCK_drizzle_create_db.
+    Wait for global read lock before acquiring LOCK_drizzleclient_create_db.
     After wait_if_global_read_lock() we have protection against another
-    global read lock. If we would acquire LOCK_drizzle_create_db first,
+    global read lock. If we would acquire LOCK_drizzleclient_create_db first,
     another thread could step in and get the global read lock before we
     reach wait_if_global_read_lock(). If this thread tries the same as we
-    (admin a db), it would then go and wait on LOCK_drizzle_create_db...
+    (admin a db), it would then go and wait on LOCK_drizzleclient_create_db...
     Furthermore wait_if_global_read_lock() checks if the current thread
     has the global read lock and refuses the operation with
     ER_CANT_UPDATE_WITH_READLOCK if applicable.
@@ -326,7 +326,7 @@
     goto exit2;
   }
 
-  pthread_mutex_lock(&LOCK_drizzle_create_db);
+  pthread_mutex_lock(&LOCK_drizzleclient_create_db);
 
   /* Check directory */
   path_len= build_table_filename(path, sizeof(path), db, "", "", 0);
@@ -386,7 +386,7 @@
   }
 
 exit:
-  pthread_mutex_unlock(&LOCK_drizzle_create_db);
+  pthread_mutex_unlock(&LOCK_drizzleclient_create_db);
   start_waiting_global_read_lock(session);
 exit2:
   return(error);
@@ -404,12 +404,12 @@
 
   /*
     Do not alter database if another thread is holding read lock.
-    Wait for global read lock before acquiring LOCK_drizzle_create_db.
+    Wait for global read lock before acquiring LOCK_drizzleclient_create_db.
     After wait_if_global_read_lock() we have protection against another
-    global read lock. If we would acquire LOCK_drizzle_create_db first,
+    global read lock. If we would acquire LOCK_drizzleclient_create_db first,
     another thread could step in and get the global read lock before we
     reach wait_if_global_read_lock(). If this thread tries the same as we
-    (admin a db), it would then go and wait on LOCK_drizzle_create_db...
+    (admin a db), it would then go and wait on LOCK_drizzleclient_create_db...
     Furthermore wait_if_global_read_lock() checks if the current thread
     has the global read lock and refuses the operation with
     ER_CANT_UPDATE_WITH_READLOCK if applicable.
@@ -417,7 +417,7 @@
   if ((error=wait_if_global_read_lock(session,0,1)))
     goto exit;
 
-  pthread_mutex_lock(&LOCK_drizzle_create_db);
+  pthread_mutex_lock(&LOCK_drizzleclient_create_db);
 
   /* Change options if current database is being altered. */
   path_len= build_table_filename(path, sizeof(path), db, "", "", 0);
@@ -427,7 +427,7 @@
   if (error && error != EEXIST)
   {
     /* TODO: find some witty way of getting back an error message */
-    pthread_mutex_unlock(&LOCK_drizzle_create_db);
+    pthread_mutex_unlock(&LOCK_drizzleclient_create_db);
     goto exit;
   }
 
@@ -442,7 +442,7 @@
   (void)replicator_statement(session, session->query, session->query_length);
   session->my_ok(result);
 
-  pthread_mutex_unlock(&LOCK_drizzle_create_db);
+  pthread_mutex_unlock(&LOCK_drizzleclient_create_db);
   start_waiting_global_read_lock(session);
 exit:
   return(error);
@@ -483,12 +483,12 @@
 
   /*
     Do not drop database if another thread is holding read lock.
-    Wait for global read lock before acquiring LOCK_drizzle_create_db.
+    Wait for global read lock before acquiring LOCK_drizzleclient_create_db.
     After wait_if_global_read_lock() we have protection against another
-    global read lock. If we would acquire LOCK_drizzle_create_db first,
+    global read lock. If we would acquire LOCK_drizzleclient_create_db first,
     another thread could step in and get the global read lock before we
     reach wait_if_global_read_lock(). If this thread tries the same as we
-    (admin a db), it would then go and wait on LOCK_drizzle_create_db...
+    (admin a db), it would then go and wait on LOCK_drizzleclient_create_db...
     Furthermore wait_if_global_read_lock() checks if the current thread
     has the global read lock and refuses the operation with
     ER_CANT_UPDATE_WITH_READLOCK if applicable.
@@ -499,7 +499,7 @@
     goto exit2;
   }
 
-  pthread_mutex_lock(&LOCK_drizzle_create_db);
+  pthread_mutex_lock(&LOCK_drizzleclient_create_db);
 
   length= build_table_filename(path, sizeof(path), db, "", "", 0);
   strcpy(path+length, MY_DB_OPT_FILE);         // Append db option file name
@@ -575,7 +575,7 @@
       tbl_name_len= strlen(tbl->table_name) + 3;
       if (query_pos + tbl_name_len + 1 >= query_end)
       {
-        /* These DDL methods and logging protected with LOCK_drizzle_create_db */
+        /* These DDL methods and logging protected with LOCK_drizzleclient_create_db */
         write_to_binlog(session, query, query_pos -1 - query, db, db_len);
         query_pos= query_data_start;
       }
@@ -588,7 +588,7 @@
 
     if (query_pos != query_data_start)
     {
-      /* These DDL methods and logging protected with LOCK_drizzle_create_db */
+      /* These DDL methods and logging protected with LOCK_drizzleclient_create_db */
       write_to_binlog(session, query, query_pos -1 - query, db, db_len);
     }
   }
@@ -602,7 +602,7 @@
   */
   if (session->db && !strcmp(session->db, db))
     mysql_change_db_impl(session, NULL, session->variables.collation_server);
-  pthread_mutex_unlock(&LOCK_drizzle_create_db);
+  pthread_mutex_unlock(&LOCK_drizzleclient_create_db);
   start_waiting_global_read_lock(session);
 exit2:
   return(error);

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-02-08 11:11:30 +0000
+++ drizzled/drizzled.cc	2009-02-08 11:28:58 +0000
@@ -409,7 +409,7 @@
 
 pthread_key_t THR_Mem_root;
 pthread_key_t THR_Session;
-pthread_mutex_t LOCK_drizzle_create_db, 
+pthread_mutex_t LOCK_drizzleclient_create_db, 
                 LOCK_open, 
                 LOCK_thread_count,
                 LOCK_status,
@@ -840,7 +840,7 @@
 
 static void clean_up_mutexes()
 {
-  (void) pthread_mutex_destroy(&LOCK_drizzle_create_db);
+  (void) pthread_mutex_destroy(&LOCK_drizzleclient_create_db);
   (void) pthread_mutex_destroy(&LOCK_lock_db);
   (void) pthread_mutex_destroy(&LOCK_open);
   (void) pthread_mutex_destroy(&LOCK_thread_count);
@@ -1930,7 +1930,7 @@
 
 static int init_thread_environment()
 {
-  (void) pthread_mutex_init(&LOCK_drizzle_create_db,MY_MUTEX_INIT_SLOW);
+  (void) pthread_mutex_init(&LOCK_drizzleclient_create_db,MY_MUTEX_INIT_SLOW);
   (void) pthread_mutex_init(&LOCK_lock_db,MY_MUTEX_INIT_SLOW);
   (void) pthread_mutex_init(&LOCK_open, NULL);
   (void) pthread_mutex_init(&LOCK_thread_count,MY_MUTEX_INIT_FAST);

=== modified file 'drizzled/item/param.cc'
--- drizzled/item/param.cc	2009-02-08 11:11:30 +0000
+++ drizzled/item/param.cc	2009-02-08 11:28:58 +0000
@@ -545,7 +545,7 @@
 */
 
 uint32_t
-drizzle_escape_string(char *to,const char *from, uint32_t length)
+drizzleclient_escape_string(char *to,const char *from, uint32_t length)
 {
   const char *to_start= to;
   const char *end, *to_end=to_start + 2*length;
@@ -636,7 +636,7 @@
   else
   {
     *ptr++= '\'';
-    ptr+= drizzle_escape_string(ptr, from->ptr(), from->length());
+    ptr+= drizzleclient_escape_string(ptr, from->ptr(), from->length());
     *ptr++='\'';
   }
   to->length(orig_len + ptr - beg);

=== modified file 'drizzled/protocol.cc'
--- drizzled/protocol.cc	2009-02-08 11:11:30 +0000
+++ drizzled/protocol.cc	2009-02-08 11:28:58 +0000
@@ -274,8 +274,8 @@
 
   /* The first # is to make the protocol backward compatible */
   buff[2]= '#';
-  pos= (unsigned char*) strcpy((char*) buff+3, drizzle_errno_to_sqlstate(sql_errno));
-  pos+= strlen(drizzle_errno_to_sqlstate(sql_errno));
+  pos= (unsigned char*) strcpy((char*) buff+3, drizzleclient_errno_to_sqlstate(sql_errno));
+  pos+= strlen(drizzleclient_errno_to_sqlstate(sql_errno));
 
   char *tmp= strncpy((char*)pos, err, DRIZZLE_ERRMSG_SIZE-1);
   tmp+= strlen((char*)pos);

=== modified file 'drizzled/server_includes.h'
--- drizzled/server_includes.h	2009-02-08 09:53:59 +0000
+++ drizzled/server_includes.h	2009-02-08 11:28:58 +0000
@@ -169,7 +169,7 @@
 
 extern TableList general_log, slow_log;
 extern FILE *stderror_file;
-extern pthread_mutex_t LOCK_drizzle_create_db,LOCK_open, LOCK_lock_db,
+extern pthread_mutex_t LOCK_drizzleclient_create_db,LOCK_open, LOCK_lock_db,
        LOCK_thread_count,LOCK_user_locks, LOCK_status,
        LOCK_timezone,
        LOCK_global_read_lock,

=== modified file 'drizzled/sql_state.cc'
--- drizzled/sql_state.cc	2008-11-25 22:24:30 +0000
+++ drizzled/sql_state.cc	2009-02-08 11:28:58 +0000
@@ -31,7 +31,7 @@
 
 typedef struct st_map_errno_to_sqlstate
 {
-  uint32_t drizzle_errno;
+  uint32_t drizzleclient_errno;
   const char *odbc_state;
   const char *jdbc_state;
 } errno_sqlstate_map;
@@ -249,19 +249,19 @@
 bool compare_errno_map(errno_sqlstate_map a,
                        errno_sqlstate_map b)
 {
-  return (a.drizzle_errno < b.drizzle_errno);
+  return (a.drizzleclient_errno < b.drizzleclient_errno);
 }
 
-const char *drizzle_errno_to_sqlstate(uint32_t drizzle_errno)
+const char *drizzleclient_errno_to_sqlstate(uint32_t drizzleclient_errno)
 {
 
-  errno_sqlstate_map drizzle_err_state= {drizzle_errno, NULL, NULL};
+  errno_sqlstate_map drizzle_err_state= {drizzleclient_errno, NULL, NULL};
   errno_sqlstate_map* result=
     lower_bound(&sqlstate_map[0],
                 &sqlstate_map[sizeof(sqlstate_map)/sizeof(*sqlstate_map)],
                 drizzle_err_state, compare_errno_map);
 
-  if ((*result).drizzle_errno == drizzle_errno)
+  if ((*result).drizzleclient_errno == drizzleclient_errno)
     return (*result).odbc_state;
   /* General error */
   return "HY000";

=== modified file 'drizzled/sql_state.h'
--- drizzled/sql_state.h	2008-10-07 08:30:48 +0000
+++ drizzled/sql_state.h	2009-02-08 11:28:58 +0000
@@ -20,6 +20,6 @@
 #ifndef _drizzled_sql_state_h
 #define _drizzled_sql_state_h
 
-const char *drizzle_errno_to_sqlstate(uint32_t drizzle_errno);
+const char *drizzleclient_errno_to_sqlstate(uint32_t drizzleclient_errno);
 
 #endif

=== modified file 'libdrizzleclient/Makefile.am'
--- libdrizzleclient/Makefile.am	2009-02-08 08:24:51 +0000
+++ libdrizzleclient/Makefile.am	2009-02-08 11:28:58 +0000
@@ -27,13 +27,13 @@
 					drizzle_data.h \
 					drizzle_field.h \
 					drizzle_methods.h \
-					drizzle_options.h \
 					drizzle_parameters.h \
 					drizzle_res.h \
 					drizzle_rows.h \
 					libdrizzle.h \
 					errmsg.h \
 					net_serv.h \
+					options.h \
 					pack.h \
 					password.h \
 					vio.h

=== modified file 'libdrizzleclient/client.c'
--- libdrizzleclient/client.c	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/client.c	2009-02-08 11:28:58 +0000
@@ -25,7 +25,7 @@
 
   - Things that only works for the client:
   - Trying to automaticly determinate user name if not supplied to
-    drizzle_connect()
+    drizzleclient_connect()
   - Support for reading local file with LOAD DATA LOCAL
   - SHARED memory handling
   - Prepared statements
@@ -107,8 +107,8 @@
     if (safe_read_error_hook != NULL)
       if (safe_read_error_hook(net))
         return (packet_error);
-    drizzle_disconnect(drizzle);
-    drizzle_set_error(drizzle, net->last_errno == CR_NET_PACKET_TOO_LARGE ?
+    drizzleclient_disconnect(drizzle);
+    drizzleclient_set_error(drizzle, net->last_errno == CR_NET_PACKET_TOO_LARGE ?
                       CR_NET_PACKET_TOO_LARGE : CR_SERVER_LOST,
                       drizzleclient_sqlstate_get_unknown());
     return (packet_error);
@@ -140,7 +140,7 @@
               (uint32_t) sizeof(net->last_error)-1));
     }
     else
-      drizzle_set_error(drizzle, CR_UNKNOWN_ERROR, drizzleclient_sqlstate_get_unknown());
+      drizzleclient_set_error(drizzle, CR_UNKNOWN_ERROR, drizzleclient_sqlstate_get_unknown());
     /*
       Cover a protocol design error: error packet does not
       contain the server status. Therefore, the client has no way
@@ -168,13 +168,13 @@
 
   if (drizzle->net.vio == 0)
   {            /* Do reconnect if possible */
-    if (drizzle_reconnect(drizzle) || stmt_skip)
+    if (drizzleclient_reconnect(drizzle) || stmt_skip)
       return(1);
   }
   if (drizzle->status != DRIZZLE_STATUS_READY ||
       drizzle->server_status & SERVER_MORE_RESULTS_EXISTS)
   {
-    drizzle_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC,
+    drizzleclient_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC,
                       drizzleclient_sqlstate_get_unknown());
     return(1);
   }
@@ -194,16 +194,16 @@
   {
     if (net->last_errno == CR_NET_PACKET_TOO_LARGE)
     {
-      drizzle_set_error(drizzle, CR_NET_PACKET_TOO_LARGE, drizzleclient_sqlstate_get_unknown());
+      drizzleclient_set_error(drizzle, CR_NET_PACKET_TOO_LARGE, drizzleclient_sqlstate_get_unknown());
       goto end;
     }
-    drizzle_disconnect(drizzle);
-    if (drizzle_reconnect(drizzle) || stmt_skip)
+    drizzleclient_disconnect(drizzle);
+    if (drizzleclient_reconnect(drizzle) || stmt_skip)
       goto end;
     if (drizzleclient_net_write_command(net,(unsigned char) command, header, header_length,
         arg, arg_length))
     {
-      drizzle_set_error(drizzle, CR_SERVER_GONE_ERROR, drizzleclient_sqlstate_get_unknown());
+      drizzleclient_set_error(drizzle, CR_SERVER_GONE_ERROR, drizzleclient_sqlstate_get_unknown());
       goto end;
     }
   }
@@ -243,7 +243,7 @@
 
 
 void
-drizzle_free_result(DRIZZLE_RES *result)
+drizzleclient_free_result(DRIZZLE_RES *result)
 {
   if (result)
   {
@@ -288,7 +288,7 @@
     return(0);
   if (!(result=(DRIZZLE_DATA*) malloc(sizeof(DRIZZLE_DATA))))
   {
-    drizzle_set_error(drizzle, CR_OUT_OF_MEMORY,
+    drizzleclient_set_error(drizzle, CR_OUT_OF_MEMORY,
                       drizzleclient_sqlstate_get_unknown());
     return(0);
   }
@@ -311,7 +311,7 @@
         !(cur->data= ((DRIZZLE_ROW) malloc((fields+1)*sizeof(char *)+pkt_len))))
     {
       drizzleclient_free_rows(result);
-      drizzle_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
+      drizzleclient_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
       return(0);
     }
     *prev_ptr=cur;
@@ -330,7 +330,7 @@
         if (len > (uint32_t) (end_to - to))
         {
           drizzleclient_free_rows(result);
-          drizzle_set_error(drizzle, CR_MALFORMED_PACKET,
+          drizzleclient_set_error(drizzle, CR_MALFORMED_PACKET,
                             drizzleclient_sqlstate_get_unknown());
           return(0);
         }
@@ -400,7 +400,7 @@
     {
       if (len > (uint32_t) (end_pos - pos))
       {
-        drizzle_set_error(drizzle, CR_UNKNOWN_ERROR,
+        drizzleclient_set_error(drizzle, CR_UNKNOWN_ERROR,
                           drizzleclient_sqlstate_get_unknown());
         return -1;
       }
@@ -423,7 +423,7 @@
 **************************************************************************/
 
 DRIZZLE_ROW
-drizzle_fetch_row(DRIZZLE_RES *res)
+drizzleclient_fetch_row(DRIZZLE_RES *res)
 {
   if (!res->data)
   {            /* Unbufferred fetch */
@@ -432,7 +432,7 @@
       DRIZZLE *drizzle= res->handle;
       if (drizzle->status != DRIZZLE_STATUS_USE_RESULT)
       {
-        drizzle_set_error(drizzle,
+        drizzleclient_set_error(drizzle,
                           res->unbuffered_fetch_cancelled ?
                           CR_FETCH_CANCELED : CR_COMMANDS_OUT_OF_SYNC,
                           drizzleclient_sqlstate_get_unknown());
@@ -450,7 +450,7 @@
       */
       if (drizzle->unbuffered_fetch_owner == &res->unbuffered_fetch_cancelled)
         drizzle->unbuffered_fetch_owner= 0;
-      /* Don't clear handle in drizzle_free_result */
+      /* Don't clear handle in drizzleclient_free_result */
       res->handle=0;
     }
     return((DRIZZLE_ROW) NULL);
@@ -470,12 +470,12 @@
 
 /**************************************************************************
   Get column lengths of the current row
-  If one uses drizzle_use_result, res->lengths contains the length information,
+  If one uses drizzleclient_use_result, res->lengths contains the length information,
   else the lengths are calculated from the offset between pointers.
 **************************************************************************/
 
 uint32_t *
-drizzle_fetch_lengths(DRIZZLE_RES *res)
+drizzleclient_fetch_lengths(DRIZZLE_RES *res)
 {
   DRIZZLE_ROW column;
 
@@ -488,7 +488,7 @@
 
 
 int
-drizzle_options(DRIZZLE *drizzle,enum drizzle_option option, const void *arg)
+drizzleclient_options(DRIZZLE *drizzle,enum drizzle_option option, const void *arg)
 {
   switch (option) {
   case DRIZZLE_OPT_CONNECT_TIMEOUT:
@@ -557,12 +557,12 @@
 ****************************************************************************/
 
 /* DRIZZLE_RES */
-uint64_t drizzle_num_rows(const DRIZZLE_RES *res)
+uint64_t drizzleclient_num_rows(const DRIZZLE_RES *res)
 {
   return res->row_count;
 }
 
-unsigned int drizzle_num_fields(const DRIZZLE_RES *res)
+unsigned int drizzleclient_num_fields(const DRIZZLE_RES *res)
 {
   return res->field_count;
 }
@@ -572,7 +572,7 @@
   Get version number for server in a form easy to test on
 
   SYNOPSIS
-    drizzle_get_server_version()
+    drizzleclient_get_server_version()
     drizzle Connection
 
   EXAMPLE
@@ -586,7 +586,7 @@
 */
 
 uint32_t
-drizzle_get_server_version(const DRIZZLE *drizzle)
+drizzleclient_get_server_version(const DRIZZLE *drizzle)
 {
   uint32_t major, minor, version;
   char *pos= drizzle->server_version, *end_pos;

=== modified file 'libdrizzleclient/drizzle.c'
--- libdrizzleclient/drizzle.c	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/drizzle.c	2009-02-08 11:28:58 +0000
@@ -54,7 +54,7 @@
 
 /*
   Note that the drizzle argument must be initialized with drizzle_init()
-  before calling drizzle_connect !
+  before calling drizzleclient_connect !
 */
 
 
@@ -81,16 +81,16 @@
 ****************************************************************************/
 
 DRIZZLE *
-drizzle_create(DRIZZLE *ptr)
+drizzleclient_create(DRIZZLE *ptr)
 {
 
   if (!drizzle_client_init)
   {
     drizzle_client_init=true;
 
-    if (!drizzle_get_default_port())
+    if (!drizzleclient_get_default_port())
     {
-      drizzle_set_default_port(DRIZZLE_PORT);
+      drizzleclient_set_default_port(DRIZZLE_PORT);
       {
         struct servent *serv_ptr;
         char *env;
@@ -107,10 +107,10 @@
 
 #if DRIZZLE_PORT_DEFAULT == 0
         if ((serv_ptr = getservbyname("drizzle", "tcp")))
-          drizzle_set_default_port((uint32_t) ntohs((uint16_t) serv_ptr->s_port));
+          drizzleclient_set_default_port((uint32_t) ntohs((uint16_t) serv_ptr->s_port));
 #endif
         if ((env = getenv("DRIZZLE_TCP_PORT")))
-          drizzle_set_default_port((uint32_t) atoi(env));
+          drizzleclient_set_default_port((uint32_t) atoi(env));
       }
     }
 #if defined(SIGPIPE)
@@ -124,7 +124,7 @@
 
     if (ptr == NULL)
     {
-      drizzle_set_error(NULL, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
+      drizzleclient_set_error(NULL, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
       return 0;
     }
     memset(ptr, 0, sizeof(DRIZZLE));
@@ -154,13 +154,13 @@
     By default we don't reconnect because it could silently corrupt data (after
     reconnection you potentially lose table locks, user variables, session
     variables (transactions but they are specifically dealt with in
-    drizzle_reconnect()).
+    drizzleclient_reconnect()).
     This is a change: < 5.0.3 drizzle->reconnect was set to 1 by default.
     How this change impacts existing apps:
     - existing apps which relyed on the default will see a behaviour change;
-    they will have to set reconnect=1 after drizzle_connect().
+    they will have to set reconnect=1 after drizzleclient_connect().
     - existing apps which explicitely asked for reconnection (the only way they
-    could do it was by setting drizzle.reconnect to 1 after drizzle_connect())
+    could do it was by setting drizzle.reconnect to 1 after drizzleclient_connect())
     will not see a behaviour change.
     - existing apps which explicitely asked for no reconnection
     (drizzle.reconnect=0) will not see a behaviour change.
@@ -199,7 +199,7 @@
 }
 
 DRIZZLE *
-drizzle_connect(DRIZZLE *drizzle,const char *host, const char *user,
+drizzleclient_connect(DRIZZLE *drizzle,const char *host, const char *user,
                 const char *passwd, const char *db,
                 uint32_t port,
                 const char * unix_port,
@@ -247,7 +247,7 @@
     char port_buf[NI_MAXSERV];
 
     if (!port)
-      port= drizzle_get_default_port();
+      port= drizzleclient_get_default_port();
 
     if (!host)
       host= LOCAL_HOST;
@@ -262,7 +262,7 @@
 
     if (gai_errno != 0)
     {
-      drizzle_set_extended_error(drizzle, CR_UNKNOWN_HOST, drizzleclient_sqlstate_get_unknown(),
+      drizzleclient_set_extended_error(drizzle, CR_UNKNOWN_HOST, drizzleclient_sqlstate_get_unknown(),
                                  ER(CR_UNKNOWN_HOST), host, errno);
 
       goto error;
@@ -296,7 +296,7 @@
 
   if (!net->vio)
   {
-    drizzle_set_extended_error(drizzle, CR_CONN_HOST_ERROR, drizzleclient_sqlstate_get_unknown(),
+    drizzleclient_set_extended_error(drizzle, CR_CONN_HOST_ERROR, drizzleclient_sqlstate_get_unknown(),
                                ER(CR_CONN_HOST_ERROR), host, errno);
     goto error;
   }
@@ -305,7 +305,7 @@
   {
     drizzleclient_vio_delete(net->vio);
     net->vio = 0;
-    drizzle_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
     goto error;
   }
   drizzleclient_vio_keepalive(net->vio,true);
@@ -326,7 +326,7 @@
   if (drizzle->options.connect_timeout &&
       drizzleclient_vio_poll_read(net->vio, drizzle->options.connect_timeout))
   {
-    drizzle_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
+    drizzleclient_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
                                ER(CR_SERVER_LOST_INITIAL_COMM_WAIT),
                                errno);
     goto error;
@@ -339,7 +339,7 @@
   if ((pkt_length=drizzleclient_cli_safe_read(drizzle)) == packet_error)
   {
     if (drizzle->net.last_errno == CR_SERVER_LOST)
-      drizzle_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
+      drizzleclient_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
                                  ER(CR_SERVER_LOST_INITIAL_COMM_READ),
                                  errno);
     goto error;
@@ -349,7 +349,7 @@
   drizzle->protocol_version= net->read_pos[0];
   if (drizzle->protocol_version != PROTOCOL_VERSION)
   {
-    drizzle_set_extended_error(drizzle, CR_VERSION_ERROR, drizzleclient_sqlstate_get_unknown(),
+    drizzleclient_set_extended_error(drizzle, CR_VERSION_ERROR, drizzleclient_sqlstate_get_unknown(),
                                ER(CR_VERSION_ERROR), drizzle->protocol_version,
                                PROTOCOL_VERSION);
     goto error;
@@ -383,7 +383,7 @@
   if (drizzle->options.secure_auth && passwd[0] &&
       !(drizzle->server_capabilities & CLIENT_SECURE_CONNECTION))
   {
-    drizzle_set_error(drizzle, CR_SECURE_AUTH, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_SECURE_AUTH, drizzleclient_sqlstate_get_unknown());
     goto error;
   }
 
@@ -393,7 +393,7 @@
       !(drizzle->user=strdup(user)) ||
       !(drizzle->passwd=strdup(passwd)))
   {
-    drizzle_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
     goto error;
   }
   drizzle->host= drizzle->host_info+strlen(host_info)+1;
@@ -466,7 +466,7 @@
   /* Write authentication package */
   if (drizzleclient_net_write(net, (unsigned char*) buff, (size_t) (end-buff)) || drizzleclient_net_flush(net))
   {
-    drizzle_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
+    drizzleclient_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
                                ER(CR_SERVER_LOST_SEND_AUTH),
                                errno);
     goto error;
@@ -480,7 +480,7 @@
   if ((pkt_length=drizzleclient_cli_safe_read(drizzle)) == packet_error)
   {
     if (drizzle->net.last_errno == CR_SERVER_LOST)
-      drizzle_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
+      drizzleclient_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
                                  ER(CR_SERVER_LOST_READ_AUTH),
                                  errno);
     goto error;
@@ -490,10 +490,10 @@
     net->compress=1;
 
 
-  if (db && drizzle_select_db(drizzle, db))
+  if (db && drizzleclient_select_db(drizzle, db))
   {
     if (drizzle->net.last_errno == CR_SERVER_LOST)
-      drizzle_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
+      drizzleclient_set_extended_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown(),
                                  ER(CR_SERVER_LOST_SETTING_DB),
                                  errno);
     goto error;
@@ -505,10 +505,10 @@
 error:
   {
     /* Free alloced memory */
-    drizzle_disconnect(drizzle);
-    drizzle_close_free(drizzle);
+    drizzleclient_disconnect(drizzle);
+    drizzleclient_close_free(drizzle);
     if (!(((uint32_t) client_flag) & CLIENT_REMEMBER_OPTIONS))
-      drizzle_close_free_options(drizzle);
+      drizzleclient_close_free_options(drizzle);
   }
   return(0);
 }
@@ -521,7 +521,7 @@
 **************************************************************************/
 
 int
-drizzle_select_db(DRIZZLE *drizzle, const char *db)
+drizzleclient_select_db(DRIZZLE *drizzle, const char *db)
 {
   int error;
 
@@ -534,7 +534,7 @@
   return(0);
 }
 
-bool drizzle_reconnect(DRIZZLE *drizzle)
+bool drizzleclient_reconnect(DRIZZLE *drizzle)
 {
   DRIZZLE tmp_drizzle;
   assert(drizzle);
@@ -544,14 +544,14 @@
   {
     /* Allow reconnect next time */
     drizzle->server_status&= ~SERVER_STATUS_IN_TRANS;
-    drizzle_set_error(drizzle, CR_SERVER_GONE_ERROR, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_SERVER_GONE_ERROR, drizzleclient_sqlstate_get_unknown());
     return(1);
   }
-  drizzle_create(&tmp_drizzle);
+  drizzleclient_create(&tmp_drizzle);
   tmp_drizzle.options= drizzle->options;
   tmp_drizzle.options.my_cnf_file= tmp_drizzle.options.my_cnf_group= 0;
 
-  if (!drizzle_connect(&tmp_drizzle,drizzle->host,drizzle->user,drizzle->passwd,
+  if (!drizzleclient_connect(&tmp_drizzle,drizzle->host,drizzle->user,drizzle->passwd,
                        drizzle->db, drizzle->port, 0,
                        drizzle->client_flag | CLIENT_REMEMBER_OPTIONS))
   {
@@ -567,7 +567,7 @@
   /* Don't free options as these are now used in tmp_drizzle */
   memset(&drizzle->options, 0, sizeof(drizzle->options));
   drizzle->free_me=0;
-  drizzle_close(drizzle);
+  drizzleclient_close(drizzle);
   *drizzle=tmp_drizzle;
   drizzleclient_net_clear(&drizzle->net, 1);
   drizzle->affected_rows= ~(uint64_t) 0;
@@ -578,7 +578,7 @@
   Shut down connection
 **************************************************************************/
 
-void drizzle_disconnect(DRIZZLE *drizzle)
+void drizzleclient_disconnect(DRIZZLE *drizzle)
 {
   int save_errno= errno;
   if (drizzle->net.vio != 0)
@@ -597,7 +597,7 @@
   If handle is alloced by DRIZZLE connect free it.
 *************************************************************************/
 
-void drizzle_close_free_options(DRIZZLE *drizzle)
+void drizzleclient_close_free_options(DRIZZLE *drizzle)
 {
   if (drizzle->options.user != NULL)
     free(drizzle->options.user);
@@ -618,7 +618,7 @@
 }
 
 
-void drizzle_close_free(DRIZZLE *drizzle)
+void drizzleclient_close_free(DRIZZLE *drizzle)
 {
   if (drizzle->host_info != NULL)
     free((unsigned char*) drizzle->host_info);
@@ -637,7 +637,7 @@
 }
 
 
-void drizzle_close(DRIZZLE *drizzle)
+void drizzleclient_close(DRIZZLE *drizzle)
 {
   if (drizzle)          /* Some simple safety */
   {
@@ -648,10 +648,10 @@
       drizzle->status=DRIZZLE_STATUS_READY; /* Force command */
       drizzle->reconnect=0;
       simple_command(drizzle,COM_QUIT,(unsigned char*) 0,0,1);
-      drizzle_disconnect(drizzle);      /* Sets drizzle->net.vio= 0 */
+      drizzleclient_disconnect(drizzle);      /* Sets drizzle->net.vio= 0 */
     }
-    drizzle_close_free_options(drizzle);
-    drizzle_close_free(drizzle);
+    drizzleclient_close_free_options(drizzle);
+    drizzleclient_close_free(drizzle);
     if (drizzle->free_me)
       free((unsigned char*) drizzle);
   }
@@ -689,7 +689,7 @@
 
     if (!(drizzle->options.client_flag & CLIENT_LOCAL_FILES))
     {
-      drizzle_set_error(drizzle, CR_MALFORMED_PACKET, drizzleclient_sqlstate_get_unknown());
+      drizzleclient_set_error(drizzle, CR_MALFORMED_PACKET, drizzleclient_sqlstate_get_unknown());
       return(1);
     }
 
@@ -713,21 +713,21 @@
 
 /*
   Send the query and return so we can do something else.
-  Needs to be followed by drizzle_read_query_result() when we want to
+  Needs to be followed by drizzleclient_read_query_result() when we want to
   finish processing it.
 */
 
 int32_t
-drizzle_send_query(DRIZZLE *drizzle, const char* query, uint32_t length)
+drizzleclient_send_query(DRIZZLE *drizzle, const char* query, uint32_t length)
 {
   return(simple_command(drizzle, COM_QUERY, (unsigned char*) query, length, 1));
 }
 
 
 int32_t
-drizzle_real_query(DRIZZLE *drizzle, const char *query, uint32_t length)
+drizzleclient_real_query(DRIZZLE *drizzle, const char *query, uint32_t length)
 {
-  if (drizzle_send_query(drizzle,query,length))
+  if (drizzleclient_send_query(drizzle,query,length))
     return(1);
   return((int) (*drizzle->methods->read_query_result)(drizzle));
 }
@@ -735,10 +735,10 @@
 
 /**************************************************************************
   Alloc result struct for buffered results. All rows are read to buffer.
-  drizzle_data_seek may be used.
+  drizzleclient_data_seek may be used.
 **************************************************************************/
 
-DRIZZLE_RES * drizzle_store_result(DRIZZLE *drizzle)
+DRIZZLE_RES * drizzleclient_store_result(DRIZZLE *drizzle)
 {
   DRIZZLE_RES *result;
 
@@ -746,7 +746,7 @@
     return(0);
   if (drizzle->status != DRIZZLE_STATUS_GET_RESULT)
   {
-    drizzle_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC, drizzleclient_sqlstate_get_unknown());
     return(0);
   }
   drizzle->status=DRIZZLE_STATUS_READY;    /* server is ready */
@@ -754,7 +754,7 @@
                 sizeof(uint32_t) *
                 drizzle->field_count))))
   {
-    drizzle_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
     return(0);
   }
   memset(result, 0,(sizeof(DRIZZLE_RES)+ sizeof(uint32_t) *
@@ -782,7 +782,7 @@
 
 /**************************************************************************
   Alloc struct for use with unbuffered reads. Data is fetched by domand
-  when calling to drizzle_fetch_row.
+  when calling to drizzleclient_fetch_row.
   DRIZZLE_DATA_seek is a noop.
 
   No other queries may be specified with the same DRIZZLE handle.
@@ -798,7 +798,7 @@
     return(0);
   if (drizzle->status != DRIZZLE_STATUS_GET_RESULT)
   {
-    drizzle_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC, drizzleclient_sqlstate_get_unknown());
     return(0);
   }
   if (!(result=(DRIZZLE_RES*) malloc(sizeof(*result)+
@@ -835,7 +835,7 @@
    @parma sqlstate SQL standard sqlstate
 */
 
-void drizzle_set_error(DRIZZLE *drizzle, int errcode, const char *sqlstate)
+void drizzleclient_set_error(DRIZZLE *drizzle, int errcode, const char *sqlstate)
 {
   NET *net;
   assert(drizzle != 0);
@@ -856,13 +856,13 @@
 }
 
 
-unsigned int drizzle_errno(const DRIZZLE *drizzle)
+unsigned int drizzleclient_errno(const DRIZZLE *drizzle)
 {
   return drizzle ? drizzle->net.last_errno : drizzle_server_last_errno;
 }
 
 
-const char * drizzle_error(const DRIZZLE *drizzle)
+const char * drizzleclient_error(const DRIZZLE *drizzle)
 {
   return drizzle ? _(drizzle->net.last_error) : _(drizzle_server_last_error);
 }
@@ -878,7 +878,7 @@
    @param ...       variable number of arguments
 */
 
-void drizzle_set_extended_error(DRIZZLE *drizzle, int errcode,
+void drizzleclient_set_extended_error(DRIZZLE *drizzle, int errcode,
                                 const char *sqlstate,
                                 const char *format, ...)
 {
@@ -925,7 +925,7 @@
 
 /**************************************************************************
   Get column lengths of the current row
-  If one uses drizzle_use_result, res->lengths contains the length information,
+  If one uses drizzleclient_use_result, res->lengths contains the length information,
   else the lengths are calculated from the offset between pointers.
 **************************************************************************/
 

=== modified file 'libdrizzleclient/drizzle.h'
--- libdrizzleclient/drizzle.h	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/drizzle.h	2009-02-08 11:28:58 +0000
@@ -22,7 +22,7 @@
 
 #include <drizzled/common.h>
 #include "drizzle_field.h"
-#include "drizzle_options.h"
+#include "options.h"
 #include "drizzle_res.h"
 #include "net_serv.h"
 
@@ -61,9 +61,9 @@
   uint32_t  server_status;
   uint32_t  server_language;
   uint32_t  warning_count;
-  struct st_drizzle_options options;
+  struct st_drizzleclient_options options;
   enum drizzle_status status;
-  bool  free_me;    /* If free in drizzle_close */
+  bool  free_me;    /* If free in drizzleclient_close */
   bool  reconnect;    /* set to 1 if automatic reconnect */
 
   /* session-wide random string */
@@ -83,8 +83,8 @@
   void *extension;
 } DRIZZLE;
 
-DRIZZLE * drizzle_create(DRIZZLE *drizzle);
-DRIZZLE * drizzle_connect(DRIZZLE *drizzle, const char *host,
+DRIZZLE * drizzleclient_create(DRIZZLE *drizzle);
+DRIZZLE * drizzleclient_connect(DRIZZLE *drizzle, const char *host,
              const char *user,
              const char *passwd,
              const char *db,
@@ -92,26 +92,26 @@
              const char *unix_socket,
              uint32_t clientflag);
 
-int32_t    drizzle_select_db(DRIZZLE *drizzle, const char *db);
-int32_t    drizzle_query(DRIZZLE *drizzle, const char *q);
-int32_t    drizzle_send_query(DRIZZLE *drizzle, const char *q, uint32_t length);
-int32_t    drizzle_real_query(DRIZZLE *drizzle, const char *q, uint32_t length);
-
-DRIZZLE_RES * drizzle_store_result(DRIZZLE *drizzle);
-DRIZZLE_RES * drizzle_use_result(DRIZZLE *drizzle);
-
-uint32_t drizzle_field_count(const DRIZZLE *drizzle);
-uint64_t drizzle_affected_rows(const DRIZZLE *drizzle);
-uint64_t drizzle_insert_id(const DRIZZLE *drizzle);
-uint32_t drizzle_errno(const DRIZZLE *drizzle);
-const char * drizzle_error(const DRIZZLE *drizzle);
-const char * drizzle_sqlstate(const DRIZZLE *drizzle);
-uint32_t drizzle_warning_count(const DRIZZLE *drizzle);
-const char * drizzle_info(const DRIZZLE *drizzle);
-uint32_t drizzle_thread_id(const DRIZZLE *drizzle);
+int32_t    drizzleclient_select_db(DRIZZLE *drizzle, const char *db);
+int32_t    drizzleclient_query(DRIZZLE *drizzle, const char *q);
+int32_t    drizzleclient_send_query(DRIZZLE *drizzle, const char *q, uint32_t length);
+int32_t    drizzleclient_real_query(DRIZZLE *drizzle, const char *q, uint32_t length);
+
+DRIZZLE_RES * drizzleclient_store_result(DRIZZLE *drizzle);
+DRIZZLE_RES * drizzleclient_use_result(DRIZZLE *drizzle);
+
+uint32_t drizzleclient_field_count(const DRIZZLE *drizzle);
+uint64_t drizzleclient_affected_rows(const DRIZZLE *drizzle);
+uint64_t drizzleclient_insert_id(const DRIZZLE *drizzle);
+uint32_t drizzleclient_errno(const DRIZZLE *drizzle);
+const char * drizzleclient_error(const DRIZZLE *drizzle);
+const char * drizzleclient_sqlstate(const DRIZZLE *drizzle);
+uint32_t drizzleclient_warning_count(const DRIZZLE *drizzle);
+const char * drizzleclient_info(const DRIZZLE *drizzle);
+uint32_t drizzleclient_thread_id(const DRIZZLE *drizzle);
 const char * drizzle_character_set_name(const DRIZZLE *drizzle);
 
-bool   drizzle_change_user(DRIZZLE *drizzle, const char *user,
+bool   drizzleclient_change_user(DRIZZLE *drizzle, const char *user,
                            const char *passwd, const char *db);
 
 /* local infile support */
@@ -119,44 +119,44 @@
 #define LOCAL_INFILE_ERROR_LEN 512
 
 void
-drizzle_set_local_infile_handler(DRIZZLE *drizzle,
+drizzleclient_set_local_infile_handler(DRIZZLE *drizzle,
         int (*local_infile_init)(void **, const char *, void *),
         int (*local_infile_read)(void *, char *, unsigned int),
         void (*local_infile_end)(void *),int (*local_infile_error)
         (void *, char*, unsigned int), void *);
 
 void
-drizzle_set_local_infile_default(DRIZZLE *drizzle);
+drizzleclient_set_local_infile_default(DRIZZLE *drizzle);
 
-int32_t    drizzle_shutdown(DRIZZLE *drizzle);
+int32_t    drizzleclient_shutdown(DRIZZLE *drizzle);
 int32_t    drizzle_dump_debug_info(DRIZZLE *drizzle);
-int32_t    drizzle_refresh(DRIZZLE *drizzle, uint32_t refresh_options);
-int32_t    drizzle_kill(DRIZZLE *drizzle, uint32_t pid);
-int32_t    drizzle_set_server_option(DRIZZLE *drizzle,
+int32_t    drizzleclient_refresh(DRIZZLE *drizzle, uint32_t refresh_options);
+int32_t    drizzleclient_kill(DRIZZLE *drizzle, uint32_t pid);
+int32_t    drizzleclient_set_server_option(DRIZZLE *drizzle,
                                      enum enum_drizzle_set_option option);
-int32_t    drizzle_ping(DRIZZLE *drizzle);
+int32_t    drizzleclient_ping(DRIZZLE *drizzle);
 const char *  drizzle_stat(DRIZZLE *drizzle);
-const char *  drizzle_get_server_info(const DRIZZLE *drizzle);
+const char *  drizzleclient_get_server_info(const DRIZZLE *drizzle);
 
-const char *  drizzle_get_host_info(const DRIZZLE *drizzle);
-uint32_t  drizzle_get_server_version(const DRIZZLE *drizzle);
-uint32_t  drizzle_get_proto_info(const DRIZZLE *drizzle);
-DRIZZLE_RES *  drizzle_list_tables(DRIZZLE *drizzle,const char *wild);
-DRIZZLE_RES *  drizzle_list_processes(DRIZZLE *drizzle);
-int32_t    drizzle_options(DRIZZLE *drizzle, enum drizzle_option option,
+const char *  drizzleclient_get_host_info(const DRIZZLE *drizzle);
+uint32_t  drizzleclient_get_server_version(const DRIZZLE *drizzle);
+uint32_t  drizzleclient_get_proto_info(const DRIZZLE *drizzle);
+DRIZZLE_RES *  drizzleclient_list_tables(DRIZZLE *drizzle,const char *wild);
+DRIZZLE_RES *  drizzleclient_list_processes(DRIZZLE *drizzle);
+int32_t    drizzleclient_options(DRIZZLE *drizzle, enum drizzle_option option,
                            const void *arg);
-DRIZZLE_RES *     drizzle_list_fields(DRIZZLE *drizzle, const char *table,
+DRIZZLE_RES *     drizzleclient_list_fields(DRIZZLE *drizzle, const char *table,
                                       const char *wild);
-bool         drizzle_read_query_result(DRIZZLE *drizzle);
+bool         drizzleclient_read_query_result(DRIZZLE *drizzle);
 
-bool drizzle_commit(DRIZZLE *drizzle);
-bool drizzle_rollback(DRIZZLE *drizzle);
-bool drizzle_autocommit(DRIZZLE *drizzle, bool auto_mode);
-bool drizzle_more_results(const DRIZZLE *drizzle);
-int drizzle_next_result(DRIZZLE *drizzle);
-void drizzle_close(DRIZZLE *drizzle);
-bool drizzle_reconnect(DRIZZLE *drizzle);
-void drizzle_disconnect(DRIZZLE *drizzle);
+bool drizzleclient_commit(DRIZZLE *drizzle);
+bool drizzleclient_rollback(DRIZZLE *drizzle);
+bool drizzleclient_autocommit(DRIZZLE *drizzle, bool auto_mode);
+bool drizzleclient_more_results(const DRIZZLE *drizzle);
+int drizzleclient_next_result(DRIZZLE *drizzle);
+void drizzleclient_close(DRIZZLE *drizzle);
+bool drizzleclient_reconnect(DRIZZLE *drizzle);
+void drizzleclient_disconnect(DRIZZLE *drizzle);
 
 bool
 drizzleclient_cli_advanced_command(DRIZZLE *drizzle, enum enum_server_command command,

=== modified file 'libdrizzleclient/drizzle_field.h'
--- libdrizzleclient/drizzle_field.h	2009-02-02 19:40:04 +0000
+++ libdrizzleclient/drizzle_field.h	2009-02-08 11:28:58 +0000
@@ -38,7 +38,7 @@
   char *org_table;            /* Org table name, if table was an alias */
   char *db;                   /* Database for table */
   char *catalog;        /* Catalog for table */
-  char *def;                  /* Default value (set by drizzle_list_fields) */
+  char *def;                  /* Default value (set by drizzleclient_list_fields) */
   uint32_t length;       /* Width of column (create length) */
   uint32_t max_length;   /* Max width for selected set */
   unsigned int name_length;

=== modified file 'libdrizzleclient/drizzle_parameters.h'
--- libdrizzleclient/drizzle_parameters.h	2009-02-02 19:40:04 +0000
+++ libdrizzleclient/drizzle_parameters.h	2009-02-08 11:28:58 +0000
@@ -33,7 +33,7 @@
   void *extension;
 } DRIZZLE_PARAMETERS;
 
-const DRIZZLE_PARAMETERS * drizzle_get_parameters(void);
+const DRIZZLE_PARAMETERS * drizzleclient_get_parameters(void);
 
 #ifdef  __cplusplus
 }

=== modified file 'libdrizzleclient/drizzle_res.h'
--- libdrizzleclient/drizzle_res.h	2009-02-02 19:40:04 +0000
+++ libdrizzleclient/drizzle_res.h	2009-02-08 11:28:58 +0000
@@ -47,7 +47,7 @@
   DRIZZLE_ROW  row;      /* If unbuffered read */
   DRIZZLE_ROW  current_row;    /* buffer to current row */
   uint32_t  field_count, current_field;
-  bool  eof;      /* Used by drizzle_fetch_row */
+  bool  eof;      /* Used by drizzleclient_fetch_row */
   /* drizzle_stmt_close() had to cancel this result */
   bool       unbuffered_fetch_cancelled;
   void *extension;
@@ -59,22 +59,22 @@
   Should definitely be used if one uses shared libraries.
 */
 
-uint64_t drizzle_num_rows(const DRIZZLE_RES *res);
-unsigned int drizzle_num_fields(const DRIZZLE_RES *res);
-bool drizzle_eof(const DRIZZLE_RES *res);
-const DRIZZLE_FIELD * drizzle_fetch_field_direct(const DRIZZLE_RES *res,
+uint64_t drizzleclient_num_rows(const DRIZZLE_RES *res);
+unsigned int drizzleclient_num_fields(const DRIZZLE_RES *res);
+bool drizzleclient_eof(const DRIZZLE_RES *res);
+const DRIZZLE_FIELD * drizzleclient_fetch_field_direct(const DRIZZLE_RES *res,
                 unsigned int fieldnr);
-const DRIZZLE_FIELD * drizzle_fetch_fields(const DRIZZLE_RES *res);
-DRIZZLE_ROW_OFFSET drizzle_row_tell(const DRIZZLE_RES *res);
-DRIZZLE_FIELD_OFFSET drizzle_field_tell(const DRIZZLE_RES *res);
+const DRIZZLE_FIELD * drizzleclient_fetch_fields(const DRIZZLE_RES *res);
+DRIZZLE_ROW_OFFSET drizzleclient_row_tell(const DRIZZLE_RES *res);
+DRIZZLE_FIELD_OFFSET drizzleclient_field_tell(const DRIZZLE_RES *res);
 
-void    drizzle_free_result(DRIZZLE_RES *result);
-void    drizzle_data_seek(DRIZZLE_RES *result, uint64_t offset);
-DRIZZLE_ROW_OFFSET drizzle_row_seek(DRIZZLE_RES *result, DRIZZLE_ROW_OFFSET offset);
-DRIZZLE_FIELD_OFFSET drizzle_field_seek(DRIZZLE_RES *result, DRIZZLE_FIELD_OFFSET offset);
-DRIZZLE_ROW  drizzle_fetch_row(DRIZZLE_RES *result);
-uint32_t * drizzle_fetch_lengths(DRIZZLE_RES *result);
-DRIZZLE_FIELD *  drizzle_fetch_field(DRIZZLE_RES *result);
+void    drizzleclient_free_result(DRIZZLE_RES *result);
+void    drizzleclient_data_seek(DRIZZLE_RES *result, uint64_t offset);
+DRIZZLE_ROW_OFFSET drizzleclient_row_seek(DRIZZLE_RES *result, DRIZZLE_ROW_OFFSET offset);
+DRIZZLE_FIELD_OFFSET drizzleclient_field_seek(DRIZZLE_RES *result, DRIZZLE_FIELD_OFFSET offset);
+DRIZZLE_ROW  drizzleclient_fetch_row(DRIZZLE_RES *result);
+uint32_t * drizzleclient_fetch_lengths(DRIZZLE_RES *result);
+DRIZZLE_FIELD *  drizzleclient_fetch_field(DRIZZLE_RES *result);
 
 #ifdef  __cplusplus
 }

=== modified file 'libdrizzleclient/libdrizzle.c'
--- libdrizzleclient/libdrizzle.c	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/libdrizzle.c	2009-02-08 11:28:58 +0000
@@ -71,17 +71,17 @@
 static DRIZZLE_PARAMETERS drizzle_internal_parameters=
 {&max_allowed_packet, &net_buffer_length, 0};
 
-const DRIZZLE_PARAMETERS * drizzle_get_parameters(void)
+const DRIZZLE_PARAMETERS * drizzleclient_get_parameters(void)
 {
   return &drizzle_internal_parameters;
 }
 
-unsigned int drizzle_get_default_port(void)
+unsigned int drizzleclient_get_default_port(void)
 {
   return drizzle_port;
 }
 
-void drizzle_set_default_port(unsigned int port)
+void drizzleclient_set_default_port(unsigned int port)
 {
   drizzle_port= port;
 }
@@ -128,7 +128,7 @@
   return 0;
 }
 
-bool drizzle_change_user(DRIZZLE *drizzle, const char *user,
+bool drizzleclient_change_user(DRIZZLE *drizzle, const char *user,
                                  const char *passwd, const char *db)
 {
   char buff[USERNAME_LENGTH+SCRAMBLED_PASSWORD_CHAR_LENGTH+NAME_LEN+2];
@@ -196,13 +196,13 @@
 
 /**************************************************************************
   Do a query. If query returned rows, free old rows.
-  Read data by drizzle_store_result or by repeat call of drizzle_fetch_row
+  Read data by drizzleclient_store_result or by repeat call of drizzleclient_fetch_row
 **************************************************************************/
 
 int
-drizzle_query(DRIZZLE *drizzle, const char *query)
+drizzleclient_query(DRIZZLE *drizzle, const char *query)
 {
-  return drizzle_real_query(drizzle,query, (uint32_t) strlen(query));
+  return drizzleclient_real_query(drizzle,query, (uint32_t) strlen(query));
 }
 
 
@@ -211,7 +211,7 @@
 **************************************************************************/
 
 DRIZZLE_FIELD *
-drizzle_fetch_field(DRIZZLE_RES *result)
+drizzleclient_fetch_field(DRIZZLE_RES *result)
 {
   if (result->current_field >= result->field_count)
     return(NULL);
@@ -224,7 +224,7 @@
 **************************************************************************/
 
 void
-drizzle_data_seek(DRIZZLE_RES *result, uint64_t row)
+drizzleclient_data_seek(DRIZZLE_RES *result, uint64_t row)
 {
   DRIZZLE_ROWS  *tmp=0;
   if (result->data)
@@ -236,12 +236,12 @@
 
 /*************************************************************************
   put the row or field cursor one a position one got from DRIZZLE_ROW_tell()
-  This doesn't restore any data. The next drizzle_fetch_row or
-  drizzle_fetch_field will return the next row or field after the last used
+  This doesn't restore any data. The next drizzleclient_fetch_row or
+  drizzleclient_fetch_field will return the next row or field after the last used
 *************************************************************************/
 
 DRIZZLE_ROW_OFFSET
-drizzle_row_seek(DRIZZLE_RES *result, DRIZZLE_ROW_OFFSET row)
+drizzleclient_row_seek(DRIZZLE_RES *result, DRIZZLE_ROW_OFFSET row)
 {
   DRIZZLE_ROW_OFFSET return_value=result->data_cursor;
   result->current_row= 0;
@@ -251,7 +251,7 @@
 
 
 DRIZZLE_FIELD_OFFSET
-drizzle_field_seek(DRIZZLE_RES *result, DRIZZLE_FIELD_OFFSET field_offset)
+drizzleclient_field_seek(DRIZZLE_RES *result, DRIZZLE_FIELD_OFFSET field_offset)
 {
   DRIZZLE_FIELD_OFFSET return_value=result->current_field;
   result->current_field=field_offset;
@@ -265,16 +265,16 @@
 *****************************************************************************/
 
 DRIZZLE_RES *
-drizzle_list_tables(DRIZZLE *drizzle, const char *wild)
+drizzleclient_list_tables(DRIZZLE *drizzle, const char *wild)
 {
   char buff[255];
   char *ptr= strcpy(buff, "show tables");
   ptr+= 11; /* strlen("show tables"); */
 
   append_wild(ptr,buff+sizeof(buff),wild);
-  if (drizzle_query(drizzle,buff))
+  if (drizzleclient_query(drizzle,buff))
     return(0);
-  return (drizzle_store_result(drizzle));
+  return (drizzleclient_store_result(drizzle));
 }
 
 
@@ -297,7 +297,7 @@
 **************************************************************************/
 
 DRIZZLE_RES *
-drizzle_list_fields(DRIZZLE *drizzle, const char *table, const char *wild)
+drizzleclient_list_fields(DRIZZLE *drizzle, const char *table, const char *wild)
 {
   DRIZZLE_RES   *result;
   DRIZZLE_FIELD *fields;
@@ -328,7 +328,7 @@
 /* List all running processes (threads) in server */
 
 DRIZZLE_RES *
-drizzle_list_processes(DRIZZLE *drizzle)
+drizzleclient_list_processes(DRIZZLE *drizzle)
 {
   DRIZZLE_DATA *fields;
   uint32_t field_count;
@@ -345,19 +345,19 @@
     return(0);
   drizzle->status=DRIZZLE_STATUS_GET_RESULT;
   drizzle->field_count=field_count;
-  return(drizzle_store_result(drizzle));
+  return(drizzleclient_store_result(drizzle));
 }
 
 
 int
-drizzle_shutdown(DRIZZLE *drizzle)
+drizzleclient_shutdown(DRIZZLE *drizzle)
 {
   return(simple_command(drizzle, COM_SHUTDOWN, 0, 0, 0));
 }
 
 
 int
-drizzle_refresh(DRIZZLE *drizzle, uint32_t options)
+drizzleclient_refresh(DRIZZLE *drizzle, uint32_t options)
 {
   unsigned char bits[1];
   bits[0]= (unsigned char) options;
@@ -366,7 +366,7 @@
 
 
 int32_t
-drizzle_kill(DRIZZLE *drizzle, uint32_t pid)
+drizzleclient_kill(DRIZZLE *drizzle, uint32_t pid)
 {
   unsigned char buff[4];
   int4store(buff,pid);
@@ -375,7 +375,7 @@
 
 
 int
-drizzle_set_server_option(DRIZZLE *drizzle, enum enum_drizzle_set_option option)
+drizzleclient_set_server_option(DRIZZLE *drizzle, enum enum_drizzle_set_option option)
 {
   unsigned char buff[2];
   int2store(buff, (uint32_t) option);
@@ -388,7 +388,7 @@
   drizzle->net.read_pos[drizzle->packet_length]=0;  /* End of stat string */
   if (!drizzle->net.read_pos[0])
   {
-    drizzle_set_error(drizzle, CR_WRONG_HOST_INFO, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_WRONG_HOST_INFO, drizzleclient_sqlstate_get_unknown());
     return drizzle->net.last_error;
   }
   return (char*) drizzle->net.read_pos;
@@ -396,7 +396,7 @@
 
 
 int
-drizzle_ping(DRIZZLE *drizzle)
+drizzleclient_ping(DRIZZLE *drizzle)
 {
   int res;
   res= simple_command(drizzle,COM_PING,0,0,0);
@@ -407,94 +407,94 @@
 
 
 const char *
-drizzle_get_server_info(const DRIZZLE *drizzle)
+drizzleclient_get_server_info(const DRIZZLE *drizzle)
 {
   return((char*) drizzle->server_version);
 }
 
 
 const char *
-drizzle_get_host_info(const DRIZZLE *drizzle)
+drizzleclient_get_host_info(const DRIZZLE *drizzle)
 {
   return(drizzle->host_info);
 }
 
 
 uint32_t
-drizzle_get_proto_info(const DRIZZLE *drizzle)
+drizzleclient_get_proto_info(const DRIZZLE *drizzle)
 {
   return (drizzle->protocol_version);
 }
 
 const char *
-drizzle_get_client_info(void)
+drizzleclient_get_client_info(void)
 {
   return (char*) VERSION;
 }
 
-uint32_t drizzle_get_client_version(void)
+uint32_t drizzleclient_get_client_version(void)
 {
   return DRIZZLE_VERSION_ID;
 }
 
-bool drizzle_eof(const DRIZZLE_RES *res)
+bool drizzleclient_eof(const DRIZZLE_RES *res)
 {
   return res->eof;
 }
 
-const DRIZZLE_FIELD * drizzle_fetch_field_direct(const DRIZZLE_RES *res, unsigned int fieldnr)
+const DRIZZLE_FIELD * drizzleclient_fetch_field_direct(const DRIZZLE_RES *res, unsigned int fieldnr)
 {
   return &(res)->fields[fieldnr];
 }
 
-const DRIZZLE_FIELD * drizzle_fetch_fields(const DRIZZLE_RES *res)
+const DRIZZLE_FIELD * drizzleclient_fetch_fields(const DRIZZLE_RES *res)
 {
   return res->fields;
 }
 
-DRIZZLE_ROW_OFFSET drizzle_row_tell(const DRIZZLE_RES *res)
+DRIZZLE_ROW_OFFSET drizzleclient_row_tell(const DRIZZLE_RES *res)
 {
   return res->data_cursor;
 }
 
-DRIZZLE_FIELD_OFFSET drizzle_field_tell(const DRIZZLE_RES *res)
+DRIZZLE_FIELD_OFFSET drizzleclient_field_tell(const DRIZZLE_RES *res)
 {
   return res->current_field;
 }
 
 /* DRIZZLE */
 
-unsigned int drizzle_field_count(const DRIZZLE *drizzle)
+unsigned int drizzleclient_field_count(const DRIZZLE *drizzle)
 {
   return drizzle->field_count;
 }
 
-uint64_t drizzle_affected_rows(const DRIZZLE *drizzle)
+uint64_t drizzleclient_affected_rows(const DRIZZLE *drizzle)
 {
   return drizzle->affected_rows;
 }
 
-uint64_t drizzle_insert_id(const DRIZZLE *drizzle)
+uint64_t drizzleclient_insert_id(const DRIZZLE *drizzle)
 {
   return drizzle->insert_id;
 }
 
-const char * drizzle_sqlstate(const DRIZZLE *drizzle)
+const char * drizzleclient_sqlstate(const DRIZZLE *drizzle)
 {
   return drizzle ? drizzle->net.sqlstate : drizzleclient_sqlstate_get_cant_connect();
 }
 
-uint32_t drizzle_warning_count(const DRIZZLE *drizzle)
+uint32_t drizzleclient_warning_count(const DRIZZLE *drizzle)
 {
   return drizzle->warning_count;
 }
 
-const char * drizzle_info(const DRIZZLE *drizzle)
+const char * drizzleclient_info(const DRIZZLE *drizzle)
 {
   return drizzle->info;
 }
 
-uint32_t drizzle_thread_id(const DRIZZLE *drizzle)
+uint32_t drizzleclient_thread_id(const DRIZZLE *drizzle)
 {
   return drizzle->thread_id;
 }
@@ -524,7 +524,7 @@
 */
 
 uint32_t
-drizzle_escape_string(char *to,const char *from, uint32_t length)
+drizzleclient_escape_string(char *to,const char *from, uint32_t length)
 {
   const char *to_start= to;
   const char *end, *to_end=to_start + 2*length;
@@ -611,18 +611,18 @@
   Commit the current transaction
 */
 
-bool drizzle_commit(DRIZZLE *drizzle)
+bool drizzleclient_commit(DRIZZLE *drizzle)
 {
-  return((bool) drizzle_real_query(drizzle, "commit", 6));
+  return((bool) drizzleclient_real_query(drizzle, "commit", 6));
 }
 
 /*
   Rollback the current transaction
 */
 
-bool drizzle_rollback(DRIZZLE *drizzle)
+bool drizzleclient_rollback(DRIZZLE *drizzle)
 {
-  return((bool) drizzle_real_query(drizzle, "rollback", 8));
+  return((bool) drizzleclient_real_query(drizzle, "rollback", 8));
 }
 
 
@@ -630,9 +630,9 @@
   Set autocommit to either true or false
 */
 
-bool drizzle_autocommit(DRIZZLE *drizzle, bool auto_mode)
+bool drizzleclient_autocommit(DRIZZLE *drizzle, bool auto_mode)
 {
-  return((bool) drizzle_real_query(drizzle, auto_mode ?
+  return((bool) drizzleclient_real_query(drizzle, auto_mode ?
                                          "set autocommit=1":"set autocommit=0",
                                          16));
 }
@@ -644,10 +644,10 @@
 
 /*
   Returns true/false to indicate whether any more query results exist
-  to be read using drizzle_next_result()
+  to be read using drizzleclient_next_result()
 */
 
-bool drizzle_more_results(const DRIZZLE *drizzle)
+bool drizzleclient_more_results(const DRIZZLE *drizzle)
 {
   return (drizzle->server_status & SERVER_MORE_RESULTS_EXISTS) ? true:false;
 }
@@ -656,11 +656,11 @@
 /*
   Reads and returns the next query results
 */
-int drizzle_next_result(DRIZZLE *drizzle)
+int drizzleclient_next_result(DRIZZLE *drizzle)
 {
   if (drizzle->status != DRIZZLE_STATUS_READY)
   {
-    drizzle_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_COMMANDS_OUT_OF_SYNC, drizzleclient_sqlstate_get_unknown());
     return(1);
   }
 
@@ -674,12 +674,12 @@
 }
 
 
-DRIZZLE_RES * drizzle_use_result(DRIZZLE *drizzle)
+DRIZZLE_RES * drizzleclient_use_result(DRIZZLE *drizzle)
 {
   return (*drizzle->methods->use_result)(drizzle);
 }
 
-bool drizzle_read_query_result(DRIZZLE *drizzle)
+bool drizzleclient_read_query_result(DRIZZLE *drizzle)
 {
   return (*drizzle->methods->read_query_result)(drizzle);
 }

=== modified file 'libdrizzleclient/libdrizzle.h'
--- libdrizzleclient/libdrizzle.h	2009-02-02 19:40:04 +0000
+++ libdrizzleclient/libdrizzle.h	2009-02-08 11:28:58 +0000
@@ -37,7 +37,7 @@
 #include "drizzle_field.h"
 #include "drizzle_rows.h"
 #include "drizzle_data.h"
-#include "drizzle_options.h"
+#include "options.h"
 
 #include "drizzle.h"
 #include "drizzle_parameters.h"
@@ -49,10 +49,10 @@
 extern "C" {
 #endif
 
-  const char * drizzle_get_client_info(void);
-  uint32_t drizzle_get_client_version(void);
-  unsigned int drizzle_get_default_port(void);
-  uint32_t drizzle_escape_string(char *to,const char *from,
+  const char * drizzleclient_get_client_info(void);
+  uint32_t drizzleclient_get_client_version(void);
+  unsigned int drizzleclient_get_default_port(void);
+  uint32_t drizzleclient_escape_string(char *to,const char *from,
                                  uint32_t from_length);
 
 #ifdef  __cplusplus

=== modified file 'libdrizzleclient/libdrizzle_priv.h'
--- libdrizzleclient/libdrizzle_priv.h	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/libdrizzle_priv.h	2009-02-08 11:28:58 +0000
@@ -45,9 +45,9 @@
 const char * drizzleclient_sqlstate_get_not_error(void);
 const char * drizzleclient_sqlstate_get_cant_connect(void);
 
-void drizzle_set_default_port(unsigned int port);
-void drizzle_set_error(DRIZZLE *drizzle, int errcode, const char *sqlstate);
-void drizzle_set_extended_error(DRIZZLE *drizzle, int errcode,
+void drizzleclient_set_default_port(unsigned int port);
+void drizzleclient_set_error(DRIZZLE *drizzle, int errcode, const char *sqlstate);
+void drizzleclient_set_extended_error(DRIZZLE *drizzle, int errcode,
                                 const char *sqlstate,
                                 const char *format, ...);
 void drizzleclient_free_old_query(DRIZZLE *drizzle);
@@ -55,8 +55,8 @@
 int drizzleclient_connect_with_timeout(int fd, const struct sockaddr *name,
                          unsigned int namelen, int32_t timeout);
 
-void drizzle_close_free_options(DRIZZLE *drizzle);
-void drizzle_close_free(DRIZZLE *drizzle);
+void drizzleclient_close_free_options(DRIZZLE *drizzle);
+void drizzleclient_close_free(DRIZZLE *drizzle);
 
 /* Hook Methods */
 bool drizzleclient_cli_read_query_result(DRIZZLE *drizzle);

=== modified file 'libdrizzleclient/local_infile.c'
--- libdrizzleclient/local_infile.c	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/local_infile.c	2009-02-08 11:28:58 +0000
@@ -66,7 +66,7 @@
   int readcount;
   void *li_ptr;          /* pass state to local_infile functions */
   char *buf;    /* buffer to be filled by local_infile_read */
-  struct st_drizzle_options *options= &drizzle->options;
+  struct st_drizzleclient_options *options= &drizzle->options;
 
   /* check that we've got valid callback functions */
   if (!(options->local_infile_init &&
@@ -75,13 +75,13 @@
   options->local_infile_error))
   {
     /* if any of the functions is invalid, set the default */
-    drizzle_set_local_infile_default(drizzle);
+    drizzleclient_set_local_infile_default(drizzle);
   }
 
   /* copy filename into local memory and allocate read buffer */
   if (!(buf=malloc(packet_length)))
   {
-    drizzle_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_OUT_OF_MEMORY, drizzleclient_sqlstate_get_unknown());
     return(1);
   }
 
@@ -113,7 +113,7 @@
   /* Send empty packet to mark end of file */
   if (drizzleclient_net_write(net, (const unsigned char*) "", 0) || drizzleclient_net_flush(net))
   {
-    drizzle_set_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown());
+    drizzleclient_set_error(drizzle, CR_SERVER_LOST, drizzleclient_sqlstate_get_unknown());
     goto err;
   }
 
@@ -278,7 +278,7 @@
 
 
 void
-drizzle_set_local_infile_handler(DRIZZLE *drizzle,
+drizzleclient_set_local_infile_handler(DRIZZLE *drizzle,
                                int (*local_infile_init)(void **, const char *,
                                void *),
                                int (*local_infile_read)(void *, char *, uint32_t),
@@ -294,7 +294,7 @@
 }
 
 
-void drizzle_set_local_infile_default(DRIZZLE *drizzle)
+void drizzleclient_set_local_infile_default(DRIZZLE *drizzle)
 {
   drizzle->options.local_infile_init=  default_local_infile_init;
   drizzle->options.local_infile_read=  default_local_infile_read;

=== modified file 'libdrizzleclient/net_serv.c'
--- libdrizzleclient/net_serv.c	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/net_serv.c	2009-02-08 11:28:58 +0000
@@ -783,7 +783,7 @@
     }
     net->read_pos = net->buff + net->where_b;
     if (len != packet_error)
-      net->read_pos[len]=0;        /* Safeguard for drizzle_use_result */
+      net->read_pos[len]=0;        /* Safeguard for drizzleclient_use_result */
     return len;
   }
   else
@@ -903,7 +903,7 @@
     len = ((uint32_t) (start_of_packet - first_packet_offset) - NET_HEADER_SIZE -
            multi_byte_packet);
     net->save_char= net->read_pos[len];    /* Must be saved */
-    net->read_pos[len]=0;        /* Safeguard for drizzle_use_result */
+    net->read_pos[len]=0;        /* Safeguard for drizzleclient_use_result */
   }
   return len;
   }

=== renamed file 'libdrizzleclient/drizzle_options.h' => 'libdrizzleclient/options.h'
--- libdrizzleclient/drizzle_options.h	2009-02-02 19:40:04 +0000
+++ libdrizzleclient/options.h	2009-02-08 11:28:58 +0000
@@ -41,7 +41,7 @@
   DRIZZLE_OPT_SSL_VERIFY_SERVER_CERT
 };
 
-struct st_drizzle_options {
+struct st_drizzleclient_options {
   unsigned int connect_timeout, read_timeout, write_timeout;
   unsigned int port;
   unsigned long client_flag;

